@@ -1,24 +1,23 @@
 use strict;
 use warnings;
-package Dist::Zilla::App;
-{
-  $Dist::Zilla::App::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::App 6.000; # TRIAL
 # ABSTRACT: Dist::Zilla's App::Cmd
-use App::Cmd::Setup 0.309 -app; # better compilation error detection
+
+use App::Cmd::Setup 0.330 -app; # better compilation error detection
 
 use Carp ();
-use Dist::Zilla::MVP::Reader::Finder;
-use Dist::Zilla::Util;
-use Moose::Autobox;
 use Try::Tiny;
 
 sub global_opt_spec {
+  my ($self) = @_;
+
   return (
-    [ "verbose|v:s@", "log additional output" ],
-    [ "lib-inc|I=s@",     "additional \@INC dirs", {
+    [ "verbose|v",           "log additional output" ],
+    [ "verbose-plugin|V=s@", "log additional output from some plugins only" ],
+    [ "lib-inc|I=s@",        "additional \@INC dirs", {
         callbacks => { 'always fine' => sub { unshift @INC, @{$_[0]}; } }
-    } ]
+    } ],
+    $self->SUPER::global_opt_spec,
   );
 }
 
@@ -32,10 +31,12 @@ sub _build_global_stashes {
 
   my $stash_registry = $self->{__global_stashes__} = {};
 
+  require Dist::Zilla::Util;
   my $config_dir  = Dist::Zilla::Util->_global_config_root;
 
-  my $config_base = $config_dir->file('config');
+  my $config_base = $config_dir->child('config');
 
+  require Dist::Zilla::MVP::Reader::Finder;
   require Dist::Zilla::MVP::Assembler::GlobalConfig;
   require Dist::Zilla::MVP::Section;
   my $assembler = Dist::Zilla::MVP::Assembler::GlobalConfig->new({
@@ -59,7 +60,20 @@ sub _build_global_stashes {
 
     my $seq = $reader->read_config($config_base, { assembler => $assembler });
   } catch {
-    die <<'END_DIE';
+    my $e = $_;
+    if (eval { $e->isa('Config::MVP::Error') and $e->ident eq 'package not installed' }) {
+      my $package = $e->package;
+
+      my $bundle = $package =~ /^@/ ? ' bundle' : '';
+      die <<"END_DIE";
+Required plugin$bundle $package isn't installed.  Remedy with:
+
+    cpanm $package
+
+END_DIE
+    }
+    else {
+      die <<'END_DIE';
 
 Your global configuration file couldn't be loaded.  It's a file matching
 ~/.dzil/config.*
@@ -69,11 +83,18 @@ format.  In most cases, this will just mean replacing [!release] with [%PAUSE]
 and deleting any [!new] stanza.  You can also delete the existing file and run
 "dzil setup"
 END_DIE
+    }
   };
 
   return $stash_registry;
 }
 
+#pod =method zilla
+#pod
+#pod This returns the Dist::Zilla object in use by the command.  If none has yet
+#pod been constructed, one will be by calling C<< Dist::Zilla->from_config >>.
+#pod
+#pod =cut
 
 sub chrome {
   my ($self) = @_;
@@ -83,11 +104,11 @@ sub chrome {
 
   $self->{__chrome__} = Dist::Zilla::Chrome::Term->new;
 
-  my @v_plugins = $self->global_options->verbose
-                ? grep { length } @{ $self->global_options->verbose }
+  my @v_plugins = $self->global_options->verbose_plugin
+                ? grep { length } @{ $self->global_options->verbose_plugin }
                 : ();
 
-  my $verbose = $self->global_options->verbose && ! @v_plugins;
+  my $verbose = $self->global_options->verbose;
 
   $self->{__chrome__}->logger->set_debug($verbose ? 1 : 0);
 
@@ -100,11 +121,11 @@ sub zilla {
   require Dist::Zilla::Dist::Builder;
 
   return $self->{'' . __PACKAGE__}{zilla} ||= do {
-    my @v_plugins = $self->global_options->verbose
-                  ? grep { length } @{ $self->global_options->verbose }
+    my @v_plugins = $self->global_options->verbose_plugin
+                  ? grep { length } @{ $self->global_options->verbose_plugin }
                   : ();
 
-    my $verbose = $self->global_options->verbose && ! @v_plugins;
+    my $verbose = $self->global_options->verbose;
 
     $self->chrome->logger->set_debug($verbose ? 1 : 0);
 
@@ -126,7 +147,7 @@ sub zilla {
 
     VERBOSE_PLUGIN: for my $plugin_name (grep { ! m{\A[-_]\z} } @v_plugins) {
       my @plugins = grep { $_->plugin_name =~ /\b\Q$plugin_name\E\b/ }
-                    $zilla->plugins->flatten;
+                    @{ $zilla->plugins };
 
       $zilla->log_fatal("can't find plugins matching $plugin_name to set debug")
         unless @plugins;
@@ -152,7 +173,7 @@ Dist::Zilla::App - Dist::Zilla's App::Cmd
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 METHODS
 
@@ -163,11 +184,11 @@ been constructed, one will be by calling C<< Dist::Zilla->from_config >>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
