@@ -1,18 +1,28 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command;
-{
-  $Dist::Zilla::App::Command::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::App::Command 6.000; # TRIAL
 # ABSTRACT: base class for dzil commands
-use App::Cmd::Setup -command;
-use Moose::Autobox;
 
+use App::Cmd::Setup -command;
+
+#pod =method zilla
+#pod
+#pod This returns the Dist::Zilla object in use by the command.  If none has yet
+#pod been constructed, one will be by calling C<< Dist::Zilla->from_config >>.
+#pod
+#pod (This method just delegates to the Dist::Zilla::App object!)
+#pod
+#pod =cut
 
 sub zilla {
   return $_[0]->app->zilla;
 }
 
+#pod =method log
+#pod
+#pod This method calls the C<log> method of the application's chrome.
+#pod
+#pod =cut
 
 sub log {
   $_[0]->app->chrome->logger->log($_[1]);
@@ -32,7 +42,7 @@ Dist::Zilla::App::Command - base class for dzil commands
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 METHODS
 
@@ -49,11 +59,11 @@ This method calls the C<log> method of the application's chrome.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
