@@ -1,14 +1,21 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command::add;
-{
-  $Dist::Zilla::App::Command::add::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::App::Command::add 6.000; # TRIAL
 # ABSTRACT: add a module to a dist
-use Dist::Zilla::App -command;
-use Path::Class;
-use File::pushd ();
 
+use Dist::Zilla::App -command;
+use Dist::Zilla::Path;
+
+#pod =head1 SYNOPSIS
+#pod
+#pod Adds a new module to a Dist::Zilla-based distribution
+#pod
+#pod   $ dzil add Some::New::Module
+#pod
+#pod There are two arguments, C<-p> and C<-P>. C<-P> specify the minting profile
+#pod provider and C<-p> - the profile name. These work just like C<dzil new>.
+#pod
+#pod =cut
 
 sub abstract { 'add modules to an existing dist' }
 
@@ -42,6 +49,8 @@ sub execute {
 
   my $zilla = $self->zilla;
   my $dist = $zilla->name;
+  
+  require File::pushd;
 
   require Dist::Zilla::Dist::Minter;
   my $minter = Dist::Zilla::Dist::Minter->_new_from_profile(
@@ -53,15 +62,17 @@ sub execute {
     },
   );
 
-  my $root = dir($zilla->root)->absolute;
+  my $root = path($zilla->root)->absolute;
   my $wd = File::pushd::pushd($minter->root);
 
+  my $factory = $minter->plugin_named(':DefaultModuleMaker');
+
   for my $name ( @$arg ) {
-    my $factory = $minter->plugin_named(':DefaultModuleMaker');
     $factory->make_module({ name => $name });
-    for my $file ( @{ $factory->zilla->files} ) {
-      $zilla->_write_out_file($file, $root);
-    }
+  }
+
+  for my $file ( @{ $factory->zilla->files} ) {
+    $zilla->_write_out_file($file, $root);
   }
 }
 
@@ -79,7 +90,7 @@ Dist::Zilla::App::Command::add - add a module to a dist
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 SYNOPSIS
 
@@ -92,11 +103,11 @@ provider and C<-p> - the profile name. These work just like C<dzil new>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
