@@ -1,12 +1,22 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command::authordeps;
-{
-  $Dist::Zilla::App::Command::authordeps::VERSION = '5.003'; # TRIAL
-}
-use Dist::Zilla::App -command;
+package Dist::Zilla::App::Command::authordeps 6.000; # TRIAL
 # ABSTRACT: List your distribution's author dependencies
 
+use Dist::Zilla::App -command;
+
+#pod =head1 SYNOPSIS
+#pod
+#pod   $ dzil authordeps
+#pod
+#pod This will scan the F<dist.ini> file and print a list of plugin modules that
+#pod probably need to be installed for the dist to be buildable.  This is a very
+#pod naive scan, but tends to be pretty accurate.  Modules can be added to its
+#pod results by using special comments in the form:
+#pod
+#pod   ; authordep Some::Package
+#pod
+#pod =cut
 
 sub abstract { "list your distribution's author dependencies" }
 
@@ -21,16 +31,16 @@ sub opt_spec {
 sub execute {
   my ($self, $opt, $arg) = @_;
 
-  require Path::Class;
+  require Dist::Zilla::Path;
   require Dist::Zilla::Util::AuthorDeps;
 
-  my $deps =
-    Dist::Zilla::Util::AuthorDeps::format_author_deps(
-      Dist::Zilla::Util::AuthorDeps::extract_author_deps(
-        Path::Class::dir(defined $opt->root ? $opt->root : '.'),
-        $opt->missing,
-      ), $opt->versions
-    );
+  my $deps = Dist::Zilla::Util::AuthorDeps::format_author_deps(
+    Dist::Zilla::Util::AuthorDeps::extract_author_deps(
+      Dist::Zilla::Path::path($opt->root // '.'),
+      $opt->missing,
+    ), $opt->versions
+  );
+
   $self->log($deps) if $deps;
 
   return;
@@ -50,7 +60,7 @@ Dist::Zilla::App::Command::authordeps - List your distribution's author dependen
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 SYNOPSIS
 
@@ -65,11 +75,11 @@ results by using special comments in the form:
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
