@@ -1,17 +1,32 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command::clean;
-{
-  $Dist::Zilla::App::Command::clean::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::App::Command::clean 6.000; # TRIAL
 # ABSTRACT: clean up after build, test, or install
+
 use Dist::Zilla::App -command;
 
+#pod =head1 SYNOPSIS
+#pod
+#pod   dzil clean [ --dry-run|-n ]
+#pod
+#pod This command removes some files that are created during build, test, and
+#pod install.  It's a very thin layer over the C<L<clean|Dist::Zilla/clean>> method
+#pod on the Dist::Zilla object.  The documentation for that method gives more
+#pod information about the files that will be removed.
+#pod
+#pod =cut
 
 sub opt_spec {
   [ 'dry-run|n'   => 'don\'t actually remove anything, just show what would be done' ],
 }
 
+#pod =head1 OPTIONS
+#pod
+#pod =head2 -n, --dry-run
+#pod
+#pod Nothing is removed; instead, everything that would be removed will be listed.
+#pod
+#pod =cut
 
 sub abstract { 'clean up after build, test, or install' }
 
@@ -35,7 +50,7 @@ Dist::Zilla::App::Command::clean - clean up after build, test, or install
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 SYNOPSIS
 
@@ -54,11 +69,11 @@ Nothing is removed; instead, everything that would be removed will be listed.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
