@@ -1,19 +1,47 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command::install;
-{
-  $Dist::Zilla::App::Command::install::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::App::Command::install 6.000; # TRIAL
 # ABSTRACT: install your dist
+
 use Dist::Zilla::App -command;
 
+#pod =head1 SYNOPSIS
+#pod
+#pod Installs your distribution using a specified command.
+#pod
+#pod     dzil install [--install-command="cmd"]
+#pod
+#pod =cut
 sub abstract { 'install your dist' }
 
+#pod =head1 EXAMPLE
+#pod
+#pod     $ dzil install
+#pod     $ dzil install --install-command="cpan ."
+#pod
+#pod =cut
 
 sub opt_spec {
   [ 'install-command=s', 'command to run to install (e.g. "cpan .")' ],
+  [ 'keep-build-dir|keep' => 'keep the build directory even after a success' ],
 }
 
+#pod =head1 OPTIONS
+#pod
+#pod =head2 --install-command
+#pod
+#pod This defines what command to run after building the dist in the dist dir.
+#pod
+#pod Any value that works with L<C<system>|perlfunc/system> is accepted.
+#pod
+#pod If not specified, calls (roughly):
+#pod
+#pod     cpanm .
+#pod
+#pod For more information, look at the L<install|Dist::Zilla::Dist::Builder/install> method in
+#pod Dist::Zilla.
+#pod
+#pod =cut
 
 sub execute {
   my ($self, $opt, $arg) = @_;
@@ -22,6 +50,9 @@ sub execute {
     $opt->install_command
       ? (install_command => [ $opt->install_command ])
       : (),
+    $opt->keep_build_dir
+      ? (keep_build_dir => 1)
+      : (),
   });
 }
 
@@ -39,7 +70,7 @@ Dist::Zilla::App::Command::install - install your dist
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 SYNOPSIS
 
@@ -69,11 +100,11 @@ Dist::Zilla.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
