@@ -1,22 +1,64 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command::listdeps;
-{
-  $Dist::Zilla::App::Command::listdeps::VERSION = '5.003'; # TRIAL
-}
-use Dist::Zilla::App -command;
+package Dist::Zilla::App::Command::listdeps 6.000; # TRIAL
 # ABSTRACT: print your distribution's prerequisites
 
+use Dist::Zilla::App -command;
+
+#pod =head1 SYNOPSIS
+#pod
+#pod   $ dzil listdeps | cpan
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This is a command plugin for L<Dist::Zilla>. It provides the C<listdeps>
+#pod command, which prints your distribution's prerequisites. You could pipe that
+#pod list to a CPAN client like L<cpan> to install all of the dependencies in one
+#pod quick go.
+#pod
+#pod =head1 OPTIONS
+#pod
+#pod =head2 --author (or --develop)
+#pod
+#pod Include author dependencies (those listed under C<develop_requires>).
+#pod
+#pod =head2 --missing
+#pod
+#pod List only dependencies which are unsatisfied.
+#pod
+#pod =head2 --versions
+#pod
+#pod Also display the required versions of listed modules.
+#pod
+#pod =head2 --cpanm-versions
+#pod
+#pod Also display the required versions of listed modules, but in a format suitable
+#pod for piping into F<cpanm>.
+#pod
+#pod =head2 --json
+#pod
+#pod Lists all prerequisites in JSON format, as they would appear in META.json
+#pod (broken out into phases and types)
+#pod
+#pod =head1 ACKNOWLEDGEMENTS
+#pod
+#pod This code was originally more or less a direct copy of Marcel Gruenauer (hanekomu)
+#pod Dist::Zilla::App::Command::prereqs, updated to work with the Dist::Zilla v2
+#pod API.
+#pod
+#pod =cut
 
 use Try::Tiny;
 
 sub abstract { "print your distribution's prerequisites" }
 
 sub opt_spec {
-  [ 'author', 'include author dependencies' ],
+  [ 'develop|author', 'include author/develop dependencies' ],
   [ 'missing', 'list only the missing dependencies' ],
   [ 'versions', 'include required version numbers in listing' ],
+  [ 'cpanm-versions', 'format versions for consumption by cpanm' ],
   [ 'json', 'list dependencies by phase, in JSON format' ],
+  [ 'omit-core=s', 'Omit dependencies that are shipped with the specified version of perl' ],
 }
 
 sub prereqs {
@@ -32,10 +74,31 @@ sub prereqs {
   my $prereqs = $zilla->prereqs;
 }
 
+my @phases = qw/configure build test runtime develop/;
+my @relationships = qw/requires recommends suggests/;
+
+sub filter_core {
+  my ($prereqs, $core_version) = @_;
+  $core_version = sprintf '%7.6f', $core_version if $core_version >= 5.010;
+  $prereqs = $prereqs->clone if $prereqs->is_finalized;
+  require Module::CoreList;
+  for my $phase (@phases) {
+    for my $relation (@relationships) {
+      my $req = $prereqs->requirements_for($phase, $relation);
+      for my $module ($req->required_modules) {
+        next if not exists $Module::CoreList::version{$core_version}{$module};
+        $req->clear_requirement($module) if $req->accepts_module($module, $Module::CoreList::version{$core_version}{$module});
+      }
+    }
+  }
+  return $prereqs;
+}
+
 sub extract_dependencies {
-  my ($self, $zilla, $phases, $missing) = @_;
+  my ($self, $zilla, $phases, $missing, $omit_core) = @_;
 
   my $prereqs = $self->prereqs($zilla);
+  $prereqs = filter_core($prereqs, $omit_core) if $omit_core;
 
   require CPAN::Meta::Requirements;
   my $req = CPAN::Meta::Requirements->new;
@@ -73,22 +136,27 @@ sub execute {
   $self->app->chrome->logger->mute;
 
   my @phases = qw(build test configure runtime);
-  push @phases, 'develop' if $opt->author;
+  push @phases, 'develop' if $opt->develop;
 
+  my $omit_core = $opt->omit_core;
   if($opt->json) {
     my $prereqs = $self->prereqs($self->zilla);
+    $prereqs = filter_core($prereqs, $omit_core) if $omit_core;
     my $output = $prereqs->as_string_hash;
 
-    require JSON; JSON->VERSION(2);
-    print JSON->new->ascii(1)->canonical(1)->pretty->encode($output), "\n";
+    require JSON::MaybeXS;
+    print JSON::MaybeXS->new(ascii => 1, canonical => 1, pretty => 1)->encode($output), "\n";
     return 1;
   }
 
-  my %modules = $self->extract_dependencies($self->zilla, \@phases, $opt->missing);
+  my %modules = $self->extract_dependencies($self->zilla, \@phases, $opt->missing, $opt->omit_core);
 
-  if($opt->versions) {
-    for(sort { lc $a cmp lc $b } keys %modules) {
-      print "$_ = ".$modules{$_}."\n";
+  if ($opt->versions or $opt->cpanm_versions) {
+    my @names = sort { lc $a cmp lc $b } keys %modules;
+    if ($opt->cpanm_versions) {
+      print qq{$_~"$modules{$_}"\n} for @names;
+    } else {
+      print "$_ = $modules{$_}\n" for @names;
     }
   } else {
       print "$_\n" for sort { lc $a cmp lc $b } keys(%modules);
@@ -109,7 +177,7 @@ Dist::Zilla::App::Command::listdeps - print your distribution's prerequisites
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 SYNOPSIS
 
@@ -124,7 +192,7 @@ quick go.
 
 =head1 OPTIONS
 
-=head2 --author
+=head2 --author (or --develop)
 
 Include author dependencies (those listed under C<develop_requires>).
 
@@ -136,6 +204,11 @@ List only dependencies which are unsatisfied.
 
 Also display the required versions of listed modules.
 
+=head2 --cpanm-versions
+
+Also display the required versions of listed modules, but in a format suitable
+for piping into F<cpanm>.
+
 =head2 --json
 
 Lists all prerequisites in JSON format, as they would appear in META.json
@@ -149,11 +222,11 @@ API.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
