@@ -1,15 +1,29 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command::nop;
-{
-  $Dist::Zilla::App::Command::nop::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::App::Command::nop 6.000; # TRIAL
 # ABSTRACT: initialize dzil, then exit
+
 use Dist::Zilla::App -command;
 
+#pod =head1 SYNOPSIS
+#pod
+#pod This command does nothing.  It initializes Dist::Zilla, then exits.  This is
+#pod useful to see the logging output of plugin initialization.
+#pod
+#pod   dzil nop -v
+#pod
+#pod Seriously, this command is almost entirely for diagnostic purposes.  Don't
+#pod overthink it, okay?
+#pod
+#pod =cut
 
 sub abstract { 'do nothing: initialize dzil, then exit' }
 
+sub description {
+  "This command does nothing but initialize Dist::Zilla and exit.\n" .
+  "It is sometimes useful for diagnostic purposes."
+}
+
 sub execute {
   my ($self, $opt, $arg) = @_;
 
@@ -30,7 +44,7 @@ Dist::Zilla::App::Command::nop - initialize dzil, then exit
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 SYNOPSIS
 
@@ -44,11 +58,11 @@ overthink it, okay?
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
