@@ -1,12 +1,22 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command::release;
-{
-  $Dist::Zilla::App::Command::release::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::App::Command::release 6.000; # TRIAL
 # ABSTRACT: release your dist to the CPAN
+
 use Dist::Zilla::App -command;
 
+#pod =head1 SYNOPSIS
+#pod
+#pod   dzil release
+#pod
+#pod   dzil release --trial
+#pod
+#pod This command is a very, very thin wrapper around the
+#pod C<L<release|Dist::Zilla/release>> method on the Dist::Zilla object.  It will
+#pod build, archive, and release your distribution using your Releaser plugins.  The
+#pod only option, C<--trial>, will cause it to build a trial build.
+#pod
+#pod =cut
 
 sub abstract { 'release your dist' }
 
@@ -17,9 +27,13 @@ sub opt_spec {
 sub execute {
   my ($self, $opt, $arg) = @_;
 
-  my $zilla = $self->zilla;
-
-  $zilla->is_trial(1) if $opt->trial;
+  my $zilla;
+  {
+    # isolate changes to RELEASE_STATUS to zilla construction
+    local $ENV{RELEASE_STATUS} = $ENV{RELEASE_STATUS};
+    $ENV{RELEASE_STATUS} = 'testing' if $opt->trial;
+    $zilla = $self->zilla;
+  }
 
   $self->zilla->release;
 }
@@ -38,7 +52,7 @@ Dist::Zilla::App::Command::release - release your dist to the CPAN
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 SYNOPSIS
 
@@ -53,11 +67,11 @@ only option, C<--trial>, will cause it to build a trial build.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
