@@ -1,12 +1,34 @@
 use strict;
 use warnings;
-package Dist::Zilla::App::Command::smoke;
-{
-  $Dist::Zilla::App::Command::smoke::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::App::Command::smoke 6.000; # TRIAL
 # ABSTRACT: smoke your dist
+
 use Dist::Zilla::App -command;
 
+#pod =head1 SYNOPSIS
+#pod
+#pod   dzil smoke [ --release ] [ --author ] [ --no-automated ]
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This command builds and tests the distribution in "smoke testing mode."
+#pod
+#pod This command is a thin wrapper around the L<test|Dist::Zilla::Dist::Builder/test> method in
+#pod Dist::Zilla.  It builds your dist and runs the tests with the AUTOMATED_TESTING
+#pod environment variable turned on, so it's like doing this:
+#pod
+#pod   export AUTOMATED_TESTING=1
+#pod   dzil build --no-tgz
+#pod   cd $BUILD_DIRECTORY
+#pod   perl Makefile.PL
+#pod   make
+#pod   make test
+#pod
+#pod A build that fails tests will be left behind for analysis, and F<dzil> will
+#pod exit a non-zero value.  If the tests are successful, the build directory will
+#pod be removed and F<dzil> will exit with status 0.
+#pod
+#pod =cut
 
 sub opt_spec {
   [ 'release'   => 'enables the RELEASE_TESTING env variable', { default => 0 } ],
@@ -14,6 +36,21 @@ sub opt_spec {
   [ 'author' => 'enables the AUTHOR_TESTING env variable', { default => 0 } ]
 }
 
+#pod =head1 OPTIONS
+#pod
+#pod =head2 --release
+#pod
+#pod This will run the test suite with RELEASE_TESTING=1
+#pod
+#pod =head2 --no-automated
+#pod
+#pod This will run the test suite without setting AUTOMATED_TESTING
+#pod
+#pod =head2 --author
+#pod
+#pod This will run the test suite with AUTHOR_TESTING=1
+#pod
+#pod =cut
 
 sub abstract { 'smoke your dist' }
 
@@ -41,7 +78,7 @@ Dist::Zilla::App::Command::smoke - smoke your dist
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 SYNOPSIS
 
@@ -82,11 +119,11 @@ This will run the test suite with AUTHOR_TESTING=1
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
