@@ -1,16 +1,23 @@
 use strict;
 use warnings;
-
-package Dist::Zilla::App::Command::version;
-{
-  $Dist::Zilla::App::Command::version::VERSION = '5.003'; # TRIAL
-}
-use Dist::Zilla::App -command;
-use Moose;
-extends 'App::Cmd::Command::version';
-
+package Dist::Zilla::App::Command::version 6.000; # TRIAL
 # ABSTRACT: display dzil's version
 
+use Dist::Zilla::App -command;
+use App::Cmd::Command::version;
+BEGIN {
+  ## parent and base dont work here. ??? -- kentnl 2014-10-31
+  our @ISA;
+  unshift @ISA, 'App::Cmd::Command::version';
+}
+
+#pod =head1 SYNOPSIS
+#pod
+#pod Print dzil version
+#pod
+#pod   $ dzil --version or $dzil version
+#pod
+#pod =cut
 
 sub version_for_display {
   my $version_pkg = $_[0]->version_package;
@@ -33,7 +40,7 @@ Dist::Zilla::App::Command::version - display dzil's version
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 SYNOPSIS
 
@@ -43,11 +50,11 @@ Print dzil version
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
