@@ -1,18 +1,17 @@
 use strict;
-package Dist::Zilla::App::Tester;
-{
-  $Dist::Zilla::App::Tester::VERSION = '5.003'; # TRIAL
-}
+use warnings;
+package Dist::Zilla::App::Tester 6.000; # TRIAL
+# ABSTRACT: testing library for Dist::Zilla::App
+
 use parent 'App::Cmd::Tester::CaptureExternal';
 use App::Cmd::Tester 0.306 (); # result_class, ->app
-# ABSTRACT: testing library for Dist::Zilla::App
 
 use Dist::Zilla::App;
 use File::Copy::Recursive qw(dircopy);
 use File::pushd ();
 use File::Spec;
 use File::Temp;
-use Path::Class;
+use Dist::Zilla::Path;
 
 use Sub::Exporter::Util ();
 use Sub::Exporter -setup => {
@@ -26,10 +25,10 @@ sub test_dzil {
   my ($self, $source, $argv, $arg) = @_;
   $arg ||= {};
 
-  local @INC = map {; File::Spec->rel2abs($_) } @INC;
+  local @INC = map {; ref($_) ? $_ : File::Spec->rel2abs($_) } @INC;
 
   my $tmpdir = $arg->{tempdir} || File::Temp::tempdir(CLEANUP => 1);
-  my $root   = dir($tmpdir)->subdir('source');
+  my $root   = path($tmpdir)->child('source');
   $root->mkpath;
 
   dircopy($source, $root);
@@ -44,10 +43,8 @@ sub test_dzil {
 }
 
 {
-  package Dist::Zilla::App::Tester::Result;
-{
-  $Dist::Zilla::App::Tester::Result::VERSION = '5.003'; # TRIAL
-}
+  package Dist::Zilla::App::Tester::Result 6.000; # TRIAL
+
   BEGIN { our @ISA = qw(App::Cmd::Tester::Result); }
 
   sub tempdir {
@@ -96,15 +93,15 @@ Dist::Zilla::App::Tester - testing library for Dist::Zilla::App
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
