@@ -1,12 +1,17 @@
-package Dist::Zilla::Chrome::Term;
-{
-  $Dist::Zilla::Chrome::Term::VERSION = '5.003'; # TRIAL
-}
-use Moose;
+package Dist::Zilla::Chrome::Term 6.000; # TRIAL
 # ABSTRACT: chrome used for terminal-based interaction
 
+use Moose;
+
+#pod =head1 OVERVIEW
+#pod
+#pod This class provides a L<Dist::Zilla::Chrome> implementation for use in a
+#pod terminal environment.  It's the default chrome used by L<Dist::Zilla::App>.
+#pod
+#pod =cut
 
 use Dist::Zilla::Types qw(OneZero);
+use Encode ();
 use Log::Dispatchouli 1.102220;
 
 use namespace::autoclean;
@@ -21,9 +26,14 @@ has logger => (
 
 sub _build_logger {
   my $self = shift;
-  my $layer = sprintf(":encoding(%s)", $self->term_enc);
-  binmode( STDOUT, $layer );
-  binmode( STDERR, $layer );
+  my $enc = $self->term_enc;
+
+  if ($enc && Encode::resolve_alias($enc)) {
+    my $layer = sprintf(":encoding(%s)", $enc);
+    binmode( STDOUT, $layer );
+    binmode( STDERR, $layer );
+  }
+
   return Log::Dispatchouli->new({
       ident     => 'Dist::Zilla',
       to_stdout => 1,
@@ -46,7 +56,6 @@ has term_ui => (
 
 has term_enc => (
   is   => 'ro',
-  isa =>'Str',
   lazy => 1,
   default => sub {
     require Term::Encoding;
@@ -63,15 +72,22 @@ sub prompt_str {
   require Encode;
   my $term_enc = $self->term_enc;
 
+  my $encode = $term_enc
+             ? sub { Encode::encode($term_enc, shift, Encode::FB_CROAK())  }
+             : sub { shift };
+  my $decode = $term_enc
+             ? sub { Encode::decode($term_enc, shift, Encode::FB_CROAK())  }
+             : sub { shift };
+
   if ($arg->{noecho}) {
     require Term::ReadKey;
     Term::ReadKey::ReadMode('noecho');
   }
   my $input_bytes = $self->term_ui->get_reply(
-    prompt => Encode::encode($term_enc, $prompt, Encode::FB_CROAK()),
-    allow  => $check || sub { defined $_[0] and length $_[0] },
+    prompt => $encode->($prompt),
+    allow  => $check || sub { length $_[0] },
     (defined $default
-      ? (default => Encode::encode($term_enc, $default, Encode::FB_CROAK()))
+      ? (default => $encode->($default))
       : ()
     ),
   );
@@ -82,7 +98,7 @@ sub prompt_str {
     print "\n";
   }
 
-  my $input = Encode::decode($term_enc, $input_bytes, Encode::FB_CROAK());
+  my $input = $decode->($input_bytes);
   chomp $input;
 
   return $input;
@@ -136,7 +152,7 @@ Dist::Zilla::Chrome::Term - chrome used for terminal-based interaction
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 OVERVIEW
 
@@ -145,11 +161,11 @@ terminal environment.  It's the default chrome used by L<Dist::Zilla::App>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
