@@ -1,10 +1,8 @@
-package Dist::Zilla::Chrome::Test;
-{
-  $Dist::Zilla::Chrome::Test::VERSION = '5.003'; # TRIAL
-}
-use Moose;
+package Dist::Zilla::Chrome::Test 6.000; # TRIAL
 # ABSTRACT: the chrome used by Dist::Zilla::Tester
 
+use Moose;
+
 use MooseX::Types::Moose qw(ArrayRef HashRef Str);
 use Dist::Zilla::Types qw(OneZero);
 use Log::Dispatchouli 1.102220;
@@ -20,6 +18,24 @@ has logger => (
   }
 );
 
+#pod =attr response_for
+#pod
+#pod The response_for attribute (which exists only in the Test chrome) is a
+#pod hashref that lets you specify the answer to questions asked by
+#pod C<prompt_str> or C<prompt_yn>.  The key is the prompt string.  If the
+#pod value is a string, it is returned every time that question is asked.
+#pod If the value is an arrayref, the first element is shifted off and
+#pod returned every time the question is asked.  If the arrayref is empty
+#pod (or the prompt is not listed in the hash), the default answer (if any)
+#pod is returned.
+#pod
+#pod Since you can't pass arguments to the Chrome constructor, response_for
+#pod is initialized to an empty hash, and you can add entries after
+#pod construction with the C<set_response_for> method:
+#pod
+#pod   $chrome->set_response_for($prompt => $response);
+#pod
+#pod =cut
 
 has response_for => (
   isa     => HashRef[ ArrayRef | Str ],
@@ -71,7 +87,7 @@ Dist::Zilla::Chrome::Test - the chrome used by Dist::Zilla::Tester
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 ATTRIBUTES
 
@@ -94,11 +110,11 @@ construction with the C<set_response_for> method:
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
