@@ -1,28 +1,41 @@
-package Dist::Zilla::Dist::Builder;
-{
-  $Dist::Zilla::Dist::Builder::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Dist::Builder 6.000; # TRIAL
 # ABSTRACT: dist zilla subclass for building dists
+
 use Moose 0.92; # role composition fixes
 extends 'Dist::Zilla';
 
-use Moose::Autobox 0.09; # ->flatten
 use MooseX::Types::Moose qw(HashRef);
-use MooseX::Types::Path::Class qw(Dir File);
+use Dist::Zilla::Types qw(Path);
 
 use File::pushd ();
-use Path::Class;
-use Path::Tiny; # because more Path::* is better, eh?
+use Dist::Zilla::Path; # because more Path::* is better, eh?
 use Try::Tiny;
+use List::Util 1.45 'uniq';
 
 use namespace::autoclean;
 
+#pod =method from_config
+#pod
+#pod   my $zilla = Dist::Zilla->from_config(\%arg);
+#pod
+#pod This routine returns a new Zilla from the configuration in the current working
+#pod directory.
+#pod
+#pod This method should not be relied upon, yet.  Its semantics are B<certain> to
+#pod change.
+#pod
+#pod Valid arguments are:
+#pod
+#pod   config_class - the class to use to read the config
+#pod                  default: Dist::Zilla::MVP::Reader::Finder
+#pod
+#pod =cut
 
 sub from_config {
   my ($class, $arg) = @_;
   $arg ||= {};
 
-  my $root = dir($arg->{dist_root} || '.');
+  my $root = path($arg->{dist_root} || '.');
 
   my $sequence = $class->_load_config({
     root   => $root,
@@ -50,12 +63,11 @@ sub _setup_default_plugins {
         my ($file, $self) = @_;
         local $_ = $file->name;
         return 1 if m{\Alib/} and m{\.(pm|pod)$};
-        return 1 if $_ eq $self->zilla->main_module;
         return;
       },
     });
 
-    $self->plugins->push($plugin);
+    push @{ $self->plugins }, $plugin;
   }
 
   unless ($self->plugin_named(':IncModules')) {
@@ -72,7 +84,7 @@ sub _setup_default_plugins {
       },
     });
 
-    $self->plugins->push($plugin);
+    push @{ $self->plugins }, $plugin;
   }
 
   unless ($self->plugin_named(':TestFiles')) {
@@ -84,7 +96,19 @@ sub _setup_default_plugins {
       code        => sub { local $_ = $_->name; m{\At/} },
     });
 
-    $self->plugins->push($plugin);
+    push @{ $self->plugins }, $plugin;
+  }
+
+  unless ($self->plugin_named(':ExtraTestFiles')) {
+    require Dist::Zilla::Plugin::FinderCode;
+    my $plugin = Dist::Zilla::Plugin::FinderCode->new({
+      plugin_name => ':ExtraTestFiles',
+      zilla       => $self,
+      style       => 'grep',
+      code        => sub { local $_ = $_->name; m{\Axt/} },
+    });
+
+    push @{ $self->plugins }, $plugin;
   }
 
   unless ($self->plugin_named(':ExecFiles')) {
@@ -95,13 +119,32 @@ sub _setup_default_plugins {
       style       => 'list',
       code        => sub {
         my $plugins = $_[0]->zilla->plugins_with(-ExecFiles);
-        my @files = map {; @{ $_->find_files } } @$plugins;
+        my @files = uniq map {; @{ $_->find_files } } @$plugins;
 
         return \@files;
       },
     });
 
-    $self->plugins->push($plugin);
+    push @{ $self->plugins }, $plugin;
+  }
+
+  unless ($self->plugin_named(':PerlExecFiles')) {
+    require Dist::Zilla::Plugin::FinderCode;
+    my $plugin = Dist::Zilla::Plugin::FinderCode->new({
+      plugin_name => ':PerlExecFiles',
+      zilla       => $self,
+      style       => 'list',
+      code        => sub {
+        my $parent_plugin = $self->plugin_named(':ExecFiles');
+        my @files = grep {
+          $_->name =~ m{\.pl$}
+              or $_->content =~ m{^\s*\#\!.*perl\b};
+        } @{ $parent_plugin->find_files };
+        return \@files;
+      },
+    });
+
+    push @{ $self->plugins }, $plugin;
   }
 
   unless ($self->plugin_named(':ShareFiles')) {
@@ -111,25 +154,24 @@ sub _setup_default_plugins {
       zilla       => $self,
       style       => 'list',
       code        => sub {
+        my $self = shift;
         my $map = $self->zilla->_share_dir_map;
         my @files;
         if ( $map->{dist} ) {
-          push @files, $self->zilla->files->grep(sub {
-            local $_ = $_->name; m{\A\Q$map->{dist}\E/}
-          });
+          push @files, grep {; $_->name =~ m{\A\Q$map->{dist}\E/} }
+                       @{ $self->zilla->files };
         }
         if ( my $mod_map = $map->{module} ) {
           for my $mod ( keys %$mod_map ) {
-            push @files, $self->zilla->files->grep(sub {
-              local $_ = $_->name; m{\A\Q$mod_map->{$mod}\E/}
-            });
+            push @files, grep { $_->name =~ m{\A\Q$mod_map->{$mod}\E/} }
+                         @{ $self->zilla->files };
           }
         }
         return \@files;
       },
     });
 
-    $self->plugins->push($plugin);
+    push @{ $self->plugins }, $plugin;
   }
 
   unless ($self->plugin_named(':MainModule')) {
@@ -146,7 +188,31 @@ sub _setup_default_plugins {
       },
     });
 
-    $self->plugins->push($plugin);
+    push @{ $self->plugins }, $plugin;
+  }
+
+  unless ($self->plugin_named(':AllFiles')) {
+    require Dist::Zilla::Plugin::FinderCode;
+    my $plugin = Dist::Zilla::Plugin::FinderCode->new({
+      plugin_name => ':AllFiles',
+      zilla       => $self,
+      style       => 'grep',
+      code        => sub { return 1 },
+    });
+
+    push @{ $self->plugins }, $plugin;
+  }
+
+  unless ($self->plugin_named(':NoFiles')) {
+    require Dist::Zilla::Plugin::FinderCode;
+    my $plugin = Dist::Zilla::Plugin::FinderCode->new({
+      plugin_name => ':NoFiles',
+      zilla       => $self,
+      style       => 'list',
+      code        => sub { return },
+    });
+
+    push @{ $self->plugins }, $plugin;
   }
 }
 
@@ -163,7 +229,7 @@ sub _build_share_dir_map {
 
   my $share_dir_map = {};
 
-  for my $plugin ( $self->plugins_with(-ShareDir)->flatten ) {
+  for my $plugin (@{ $self->plugins_with(-ShareDir) }) {
     next unless my $sub_map = $plugin->share_dir_map;
 
     if ( $sub_map->{dist} ) {
@@ -219,7 +285,7 @@ sub _load_config {
   my $seq;
   try {
     $seq = $config_class->read_config(
-      $root->file('dist'),
+      $root->child('dist'),
       {
         assembler => $assembler
       },
@@ -231,15 +297,15 @@ sub _load_config {
     };
 
     my $package = $_->package;
+    my $bundle  = $_->section_name =~ m{^@(?!.*/)} ? ' bundle' : '';
 
-    my $bundle = $package =~ /^@/ ? ' bundle' : '';
     die <<"END_DIE";
 Required plugin$bundle $package isn't installed.
 
 Run 'dzil authordeps' to see a list of all required plugins.
 You can pipe the list to your CPAN client to install or update them:
 
-    dzil authordeps | cpanm
+    dzil authordeps --missing | cpanm
 
 END_DIE
 
@@ -248,6 +314,21 @@ END_DIE
   return $seq;
 }
 
+#pod =method build_in
+#pod
+#pod   $zilla->build_in($root);
+#pod
+#pod This method builds the distribution in the given directory.  If no directory
+#pod name is given, it defaults to DistName-Version.  If the distribution has
+#pod already been built, an exception will be thrown.
+#pod
+#pod =method build
+#pod
+#pod This method just calls C<build_in> with no arguments.  It gets you the default
+#pod behavior without the weird-looking formulation of C<build_in> with no object
+#pod for the preposition!
+#pod
+#pod =cut
 
 sub build { $_[0]->build_in }
 
@@ -260,23 +341,26 @@ sub build_in {
   $self->log_fatal("attempted to build " . $self->name . " a second time")
     if $self->built_in;
 
-  $_->before_build for $self->plugins_with(-BeforeBuild)->flatten;
+  $_->before_build for @{ $self->plugins_with(-BeforeBuild) };
 
   $self->log("beginning to build " . $self->name);
 
-  $_->gather_files       for $self->plugins_with(-FileGatherer)->flatten;
-  $_->set_file_encodings for $self->plugins_with(-EncodingProvider)->flatten;
-  $_->prune_files        for $self->plugins_with(-FilePruner)->flatten;
-  $_->munge_files        for $self->plugins_with(-FileMunger)->flatten;
+  $_->gather_files       for @{ $self->plugins_with(-FileGatherer) };
+  $_->set_file_encodings for @{ $self->plugins_with(-EncodingProvider) };
+  $_->prune_files        for @{ $self->plugins_with(-FilePruner) };
 
-  $_->register_prereqs for $self->plugins_with(-PrereqSource)->flatten;
+  $self->version; # instantiate this lazy attribute now that files are gathered
+
+  $_->munge_files        for @{ $self->plugins_with(-FileMunger) };
+
+  $_->register_prereqs   for @{ $self->plugins_with(-PrereqSource) };
 
   $self->prereqs->finalize;
 
   # Barf if someone has already set up a prereqs entry? -- rjbs, 2010-04-13
   $self->distmeta->{prereqs} = $self->prereqs->as_string_hash;
 
-  $_->setup_installer for $self->plugins_with(-InstallTool)->flatten;
+  $_->setup_installer for @{ $self->plugins_with(-InstallTool) };
 
   $self->_check_dupe_files;
 
@@ -284,23 +368,43 @@ sub build_in {
 
   $self->log("writing " . $self->name . " in $build_root");
 
-  for my $file ($self->files->flatten) {
+  for my $file (@{ $self->files }) {
     $self->_write_out_file($file, $build_root);
   }
 
   $_->after_build({ build_root => $build_root })
-    for $self->plugins_with(-AfterBuild)->flatten;
+    for @{ $self->plugins_with(-AfterBuild) };
 
   $self->built_in($build_root);
 }
 
+#pod =attr built_in
+#pod
+#pod This is the L<Path::Tiny>, if any, in which the dist has been built.
+#pod
+#pod =cut
 
 has built_in => (
   is   => 'rw',
-  isa  => Dir,
+  isa  => Path,
   init_arg  => undef,
+  coerce => 1,
 );
 
+#pod =method ensure_built_in
+#pod
+#pod   $zilla->ensure_built_in($root);
+#pod
+#pod This method behaves like C<L</build_in>>, but if the dist is already built in
+#pod C<$root> (or the default root, if no root is given), no exception is raised.
+#pod
+#pod =method ensure_built
+#pod
+#pod This method just calls C<ensure_built_in> with no arguments.  It gets you the
+#pod default behavior without the weird-looking formulation of C<ensure_built_in>
+#pod with no object for the preposition!
+#pod
+#pod =cut
 
 sub ensure_built {
   $_[0]->ensure_built_in;
@@ -317,6 +421,15 @@ sub ensure_built_in {
   $self->build_in($root);
 }
 
+#pod =method dist_basename
+#pod
+#pod   my $basename = $zilla->dist_basename;
+#pod
+#pod This method will return the dist's basename (e.g. C<Dist-Name-1.01>.
+#pod The basename is used as the top-level directory in the tarball.  It
+#pod does not include C<-TRIAL>, even if building a trial dist.
+#pod
+#pod =cut
 
 sub dist_basename {
   my ($self) = @_;
@@ -327,16 +440,34 @@ sub dist_basename {
   );
 }
 
+#pod =method archive_filename
+#pod
+#pod   my $tarball = $zilla->archive_filename;
+#pod
+#pod This method will return the filename (e.g. C<Dist-Name-1.01.tar.gz>)
+#pod of the tarball of this distribution.  It will include C<-TRIAL> if building a
+#pod trial distribution, unless the version contains an underscore.  The tarball
+#pod might not exist.
+#pod
+#pod =cut
 
 sub archive_filename {
   my ($self) = @_;
   return join(q{},
     $self->dist_basename,
-    ( $self->is_trial ? '-TRIAL' : '' ),
+    ( $self->is_trial && $self->version !~ /_/ ? '-TRIAL' : '' ),
     '.tar.gz'
   );
 }
 
+#pod =method build_archive
+#pod
+#pod   $zilla->build_archive;
+#pod
+#pod This method will ensure that the dist has been built, and will then build a
+#pod tarball of the build directory in the current directory.
+#pod
+#pod =cut
 
 sub build_archive {
   my ($self) = @_;
@@ -344,9 +475,9 @@ sub build_archive {
   my $built_in = $self->ensure_built;
 
   my $basename = $self->dist_basename;
-  my $basedir = dir($basename);
+  my $basedir = path($basename);
 
-  $_->before_archive for $self->plugins_with(-BeforeArchive)->flatten;
+  $_->before_archive for @{ $self->plugins_with(-BeforeArchive) };
 
   my $method = Class::Load::load_optional_class('Archive::Tar::Wrapper',
                                                 { -version => 0.15 })
@@ -355,7 +486,7 @@ sub build_archive {
 
   my $archive = $self->$method($built_in, $basename, $basedir);
 
-  my $file = file($self->archive_filename);
+  my $file = path($self->archive_filename);
 
   $self->log("writing archive to $file");
   $archive->write("$file", 9);
@@ -372,21 +503,21 @@ sub _build_archive {
   my $archive = Archive::Tar->new;
   my %seen_dir;
   for my $distfile (
-    sort { length($a->name) <=> length($b->name) } $self->files->flatten
+    sort { length($a->name) <=> length($b->name) } @{ $self->files }
   ) {
-    my $in = file($distfile->name)->dir;
+    my $in = path($distfile->name)->parent;
 
     unless ($seen_dir{ $in }++) {
       $archive->add_data(
-        $basedir->subdir($in),
+        $basedir->child($in),
         '',
         { type => Archive::Tar::Constant::DIR(), mode => 0755 },
       )
     }
 
-    my $filename = $built_in->file( $distfile->name );
+    my $filename = $built_in->child( $distfile->name );
     $archive->add_data(
-      $basedir->file( $distfile->name ),
+      $basedir->child( $distfile->name ),
       path($filename)->slurp_raw,
       { mode => (stat $filename)[2] & ~022 },
     );
@@ -403,13 +534,13 @@ sub _build_archive_with_wrapper {
   my $archive = Archive::Tar::Wrapper->new;
 
   for my $distfile (
-    sort { length($a->name) <=> length($b->name) } $self->files->flatten
+    sort { length($a->name) <=> length($b->name) } @{ $self->files }
   ) {
-    my $in = file($distfile->name)->dir;
+    my $in = path($distfile->name)->parent;
 
-    my $filename = $built_in->file( $distfile->name );
+    my $filename = $built_in->child( $distfile->name );
     $archive->add(
-      $basedir->file( $distfile->name )->stringify,
+      $basedir->child( $distfile->name )->stringify,
       $filename->stringify,
       { perm => (stat $filename)[2] & ~022 },
     );
@@ -421,38 +552,69 @@ sub _build_archive_with_wrapper {
 sub _prep_build_root {
   my ($self, $build_root) = @_;
 
-  $build_root = dir($build_root || $self->dist_basename);
+  $build_root = path($build_root || $self->dist_basename);
 
   $build_root->mkpath unless -d $build_root;
 
   my $dist_root = $self->root;
 
-  $build_root->rmtree if -d $build_root;
+  return $build_root if !-d $build_root;
+
+  my $ok = eval { $build_root->remove_tree({ safe => 0 }); 1 };
+  die "unable to delete '$build_root' in preparation of build: $@" unless $ok;
+
+  # the following is done only on windows, and only if the deletion failed,
+  # yet rmtree reported success, because currently rmdir is non-blocking as per:
+  # https://rt.perl.org/Ticket/Display.html?id=123958
+  if ( $^O eq 'MSWin32' and -d $build_root ) {
+    $self->log("spinning for at least one second to allow other processes to release locks on $build_root");
+    my $timeout = time + 2;
+    while(time != $timeout and -d $build_root) { }
+    die "unable to delete '$build_root' in preparation of build because some process has a lock on it"
+      if -d $build_root;
+  }
 
   return $build_root;
 }
 
+#pod =method release
+#pod
+#pod   $zilla->release;
+#pod
+#pod This method releases the distribution, probably by uploading it to the CPAN.
+#pod The actual effects of this method (as with most of the methods) is determined
+#pod by the loaded plugins.
+#pod
+#pod =cut
 
 sub release {
   my $self = shift;
 
   Carp::croak("you can't release without any Releaser plugins")
-    unless my @releasers = $self->plugins_with(-Releaser)->flatten;
+    unless my @releasers = @{ $self->plugins_with(-Releaser) };
 
   $ENV{DZIL_RELEASING} = 1;
 
   my $tgz = $self->build_archive;
 
   # call all plugins implementing BeforeRelease role
-  $_->before_release($tgz) for $self->plugins_with(-BeforeRelease)->flatten;
+  $_->before_release($tgz) for @{ $self->plugins_with(-BeforeRelease) };
 
   # do the actual release
   $_->release($tgz) for @releasers;
 
   # call all plugins implementing AfterRelease role
-  $_->after_release($tgz) for $self->plugins_with(-AfterRelease)->flatten;
+  $_->after_release($tgz) for @{ $self->plugins_with(-AfterRelease) };
 }
 
+#pod =method clean
+#pod
+#pod This method removes temporary files and directories suspected to have been
+#pod produced by the Dist::Zilla build process.  Specifically, it deletes the
+#pod F<.build> directory and any entity that starts with the dist name and a hyphen,
+#pod like matching the glob C<Your-Dist-*>.
+#pod
+#pod =cut
 
 sub clean {
   my ($self, $dry_run) = @_;
@@ -468,16 +630,24 @@ sub clean {
   };
 }
 
+#pod =method ensure_built_in_tmpdir
+#pod
+#pod   $zilla->ensure_built_in_tmpdir;
+#pod
+#pod This method will consistently build the distribution in a temporary
+#pod subdirectory. It will return the path for the temporary build location.
+#pod
+#pod =cut
 
 sub ensure_built_in_tmpdir {
   my $self = shift;
 
   require File::Temp;
 
-  my $build_root = dir('.build');
+  my $build_root = path('.build');
   $build_root->mkpath unless -d $build_root;
 
-  my $target = dir( File::Temp::tempdir(DIR => $build_root) );
+  my $target = path( File::Temp::tempdir(DIR => $build_root) );
   $self->log("building distribution under $target for installation");
 
   my $os_has_symlinks = eval { symlink("",""); 1 };
@@ -485,8 +655,8 @@ sub ensure_built_in_tmpdir {
   my $latest;
 
   if( $os_has_symlinks ) {
-    $previous = file( $build_root, 'previous' );
-    $latest   = file( $build_root, 'latest'   );
+    $previous = path( $build_root, 'previous' );
+    $latest   = path( $build_root, 'latest'   );
     if( -l $previous ) {
       $previous->remove
         or $self->log("cannot remove old .build/previous link");
@@ -504,6 +674,24 @@ sub ensure_built_in_tmpdir {
   return ($target, $latest, $previous);
 }
 
+#pod =method install
+#pod
+#pod   $zilla->install( \%arg );
+#pod
+#pod This method installs the distribution locally.  The distribution will be built
+#pod in a temporary subdirectory, then the process will change directory to that
+#pod subdir and an installer will be run.
+#pod
+#pod Valid arguments are:
+#pod
+#pod   keep_build_dir  - if true, don't rmtree the build dir, even if everything
+#pod                     seemed to work
+#pod   install_command - the command to run in the subdir to install the dist
+#pod                     default (roughly): $^X -MCPAN -einstall .
+#pod
+#pod                     this argument should be an arrayref
+#pod
+#pod =cut
 
 sub install {
   my ($self, $arg) = @_;
@@ -511,7 +699,7 @@ sub install {
 
   my ($target, $latest) = $self->ensure_built_in_tmpdir;
 
-  eval {
+  my $ok = eval {
     ## no critic Punctuation
     my $wd = File::pushd::pushd($target);
     my @cmd = $arg->{install_command}
@@ -520,57 +708,102 @@ sub install {
 
     $self->log_debug([ 'installing via %s', \@cmd ]);
     system(@cmd) && $self->log_fatal([ "error running %s", \@cmd ]);
+    1;
   };
 
-  if ($@) {
-    $self->log($@);
-    $self->log("left failed dist in place at $target");
+  unless ($ok) {
+    my $error = $@ || '(exception clobered)';
+    $self->log("install failed, left failed dist in place at $target");
+    die $error;
+  }
+
+  if ($arg->{keep_build_dir}) {
+    $self->log("all's well; left dist in place at $target");
   } else {
     $self->log("all's well; removing $target");
-    $target->rmtree;
+    $target->remove_tree({ safe => 0 });
     $latest->remove if $latest;
   }
 
   return;
 }
 
+#pod =method test
+#pod
+#pod   $zilla->test(\%arg);
+#pod
+#pod This method builds a new copy of the distribution and tests it using
+#pod C<L</run_tests_in>>.
+#pod
+#pod C<\%arg> may be omitted.  Otherwise, valid arguments are:
+#pod
+#pod   keep_build_dir  - if true, don't rmtree the build dir, even if everything
+#pod                     seemed to work
+#pod
+#pod =cut
 
 sub test {
-  my ($self) = @_;
+  my ($self, $arg) = @_;
 
   Carp::croak("you can't test without any TestRunner plugins")
-    unless my @testers = $self->plugins_with(-TestRunner)->flatten;
+    unless my @testers = @{ $self->plugins_with(-TestRunner) };
 
   my ($target, $latest) = $self->ensure_built_in_tmpdir;
-  my $error  = $self->run_tests_in($target);
+  my $error  = $self->run_tests_in($target, $arg);
+
+  if ($arg and $arg->{keep_build_dir}) {
+    $self->log("all's well; left dist in place at $target");
+    return;
+  }
 
   $self->log("all's well; removing $target");
-  $target->rmtree;
+  $target->remove_tree({ safe => 0 });
   $latest->remove if $latest;
 }
 
+#pod =method run_tests_in
+#pod
+#pod   my $error = $zilla->run_tests_in($directory, $arg);
+#pod
+#pod This method runs the tests in $directory (a Path::Tiny), which must contain an
+#pod already-built copy of the distribution.  It will throw an exception if there
+#pod are test failures.
+#pod
+#pod It does I<not> set any of the C<*_TESTING> environment variables, nor
+#pod does it clean up C<$directory> afterwards.
+#pod
+#pod =cut
 
 sub run_tests_in {
-  my ($self, $target) = @_;
+  my ($self, $target, $arg) = @_;
 
   Carp::croak("you can't test without any TestRunner plugins")
-    unless my @testers = $self->plugins_with(-TestRunner)->flatten;
+    unless my @testers = @{ $self->plugins_with(-TestRunner) };
 
   for my $tester (@testers) {
     my $wd = File::pushd::pushd($target);
-    $tester->test( $target );
+    $tester->test( $target, $arg );
   }
 }
 
+#pod =method run_in_build
+#pod
+#pod   $zilla->run_in_build( \@cmd );
+#pod
+#pod This method makes a temporary directory, builds the distribution there,
+#pod executes all the dist's L<BuildRunner|Dist::Zilla::Role::BuildRunner>s
+#pod (unless directed not to, via C<< $arg->{build} = 0 >>), and
+#pod then runs the given command in the build directory.  If the command exits
+#pod non-zero, the directory will be left in place.
+#pod
+#pod =cut
 
 sub run_in_build {
-  my ($self, $cmd) = @_;
+  my ($self, $cmd, $arg) = @_;
 
-  # The sort below is a cheap hack to get ModuleBuild ahead of
-  # ExtUtils::MakeMaker. -- rjbs, 2010-01-05
   $self->log_fatal("you can't build without any BuildRunner plugins")
-    unless my @builders =
-    $self->plugins_with(-BuildRunner)->sort->reverse->flatten;
+    unless ($arg and exists $arg->{build} and ! $arg->{build})
+        or @{ $self->plugins_with(-BuildRunner) };
 
   require "Config.pm"; # skip autoprereq
 
@@ -580,14 +813,20 @@ sub run_in_build {
   # building the dist for real
   my $ok = eval {
     my $wd = File::pushd::pushd($target);
-    $builders[0]->build;
+
+    if ($arg and exists $arg->{build} and ! $arg->{build}) {
+      system(@$cmd) and die "error while running: @$cmd";
+      return 1;
+    }
+
+    $self->_ensure_blib;
 
     local $ENV{PERL5LIB} = join $Config::Config{path_sep},
-      (map { $abstarget->subdir('blib', $_) } qw(arch lib)),
+      (map { $abstarget->child('blib', $_) } qw(arch lib)),
       (defined $ENV{PERL5LIB} ? $ENV{PERL5LIB} : ());
 
     local $ENV{PATH} = join $Config::Config{path_sep},
-      (map { $abstarget->subdir('blib', $_) } qw(bin script)),
+      (map { $abstarget->child('blib', $_) } qw(bin script)),
       (defined $ENV{PATH} ? $ENV{PATH} : ());
 
     system(@$cmd) and die "error while running: @$cmd";
@@ -596,7 +835,7 @@ sub run_in_build {
 
   if ($ok) {
     $self->log("all's well; removing $target");
-    $target->rmtree;
+    $target->remove_tree({ safe => 0 });
     $latest->remove if $latest;
   } else {
     my $error = $@ || '(unknown error)';
@@ -605,6 +844,21 @@ sub run_in_build {
   }
 }
 
+# Ensures that a F<blib> directory exists in the build, by invoking all
+# C<-BuildRunner> plugins to generate it.  Useful for commands that operate on
+# F<blib>, such as C<test> or C<run>.
+
+sub _ensure_blib {
+  my ($self) = @_;
+
+  unless ( -d 'blib' ) {
+    my @builders = @{ $self->plugins_with( -BuildRunner ) };
+    $self->log_fatal("no BuildRunner plugins specified") unless @builders;
+    $_->build for @builders;
+    $self->log_fatal("no blib; failed to build properly?") unless -d 'blib';
+  }
+}
+
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -620,13 +874,13 @@ Dist::Zilla::Dist::Builder - dist zilla subclass for building dists
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 ATTRIBUTES
 
 =head2 built_in
 
-This is the L<Path::Class::Dir>, if any, in which the dist has been built.
+This is the L<Path::Tiny>, if any, in which the dist has been built.
 
 =head1 METHODS
 
@@ -685,8 +939,9 @@ does not include C<-TRIAL>, even if building a trial dist.
   my $tarball = $zilla->archive_filename;
 
 This method will return the filename (e.g. C<Dist-Name-1.01.tar.gz>)
-of the tarball of this dist.  It will include C<-TRIAL> if building a
-trial dist.  The tarball might not exist.
+of the tarball of this distribution.  It will include C<-TRIAL> if building a
+trial distribution, unless the version contains an underscore.  The tarball
+might not exist.
 
 =head2 build_archive
 
@@ -727,6 +982,8 @@ subdir and an installer will be run.
 
 Valid arguments are:
 
+  keep_build_dir  - if true, don't rmtree the build dir, even if everything
+                    seemed to work
   install_command - the command to run in the subdir to install the dist
                     default (roughly): $^X -MCPAN -einstall .
 
@@ -734,18 +991,23 @@ Valid arguments are:
 
 =head2 test
 
-  $zilla->test;
+  $zilla->test(\%arg);
 
 This method builds a new copy of the distribution and tests it using
 C<L</run_tests_in>>.
 
+C<\%arg> may be omitted.  Otherwise, valid arguments are:
+
+  keep_build_dir  - if true, don't rmtree the build dir, even if everything
+                    seemed to work
+
 =head2 run_tests_in
 
-  my $error = $zilla->run_tests_in($directory);
+  my $error = $zilla->run_tests_in($directory, $arg);
 
-This method runs the tests in $directory (a Path::Class::Dir), which
-must contain an already-built copy of the distribution.  It will throw an
-exception if there are test failures.
+This method runs the tests in $directory (a Path::Tiny), which must contain an
+already-built copy of the distribution.  It will throw an exception if there
+are test failures.
 
 It does I<not> set any of the C<*_TESTING> environment variables, nor
 does it clean up C<$directory> afterwards.
@@ -755,17 +1017,18 @@ does it clean up C<$directory> afterwards.
   $zilla->run_in_build( \@cmd );
 
 This method makes a temporary directory, builds the distribution there,
-executes the dist's first L<BuildRunner|Dist::Zilla::Role::BuildRunner>, and
+executes all the dist's L<BuildRunner|Dist::Zilla::Role::BuildRunner>s
+(unless directed not to, via C<< $arg->{build} = 0 >>), and
 then runs the given command in the build directory.  If the command exits
 non-zero, the directory will be left in place.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
