@@ -1,13 +1,22 @@
-package Dist::Zilla::File::FromCode;
-{
-  $Dist::Zilla::File::FromCode::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::File::FromCode 6.000; # TRIAL
 # ABSTRACT: a file whose content is (re-)built on demand
+
 use Moose;
 use Moose::Util::TypeConstraints;
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This represents a file whose contents will be generated on demand from a
+#pod callback or method name.
+#pod
+#pod It has one attribute, C<code>, which may be a method name (string) or a
+#pod coderef.  When the file's C<content> method is called, the code is used to
+#pod generate the content.  This content is I<not> cached.  It is recomputed every
+#pod time the content is requested.
+#pod
+#pod =cut
 
 with 'Dist::Zilla::Role::File';
 
@@ -17,6 +26,11 @@ has code => (
   required => 1,
 );
 
+#pod =attr code_return_type
+#pod
+#pod 'text' or 'bytes'
+#pod
+#pod =cut
 
 has code_return_type => (
   is => 'ro',
@@ -24,6 +38,9 @@ has code_return_type => (
   default => 'text',
 );
 
+#pod =attr encoding
+#pod
+#pod =cut
 
 sub encoding;
 
@@ -39,6 +56,9 @@ sub _build_encoding {
   return $self->code_return_type eq 'text' ? 'UTF-8' : 'bytes';
 }
 
+#pod =attr content
+#pod
+#pod =cut
 
 sub content {
   my ($self) = @_;
@@ -56,6 +76,9 @@ sub content {
   }
 }
 
+#pod =attr encoded_content
+#pod
+#pod =cut
 
 sub encoded_content {
   my ($self) = @_;
@@ -73,9 +96,9 @@ sub encoded_content {
   }
 }
 
-around 'added_by' => sub {
-  my ($orig, $self) = @_;
-  return sprintf("%s from coderef set by %s", $self->code_return_type, $self->$orig);
+sub _set_added_by {
+  my ($self, $value) = @_;
+  return $self->_push_added_by(sprintf("%s from coderef added by %s", $self->code_return_type, $value));
 };
 
 __PACKAGE__->meta->make_immutable;
@@ -93,7 +116,7 @@ Dist::Zilla::File::FromCode - a file whose content is (re-)built on demand
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -119,11 +142,11 @@ time the content is requested.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
