@@ -1,12 +1,18 @@
-package Dist::Zilla::File::InMemory;
-{
-  $Dist::Zilla::File::InMemory::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::File::InMemory 6.000; # TRIAL
 # ABSTRACT: a file that you build entirely in memory
+
 use Moose;
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This represents a file created in memory -- it's not much more than a glorified
+#pod string.
+#pod
+#pod See L<Dist::Zilla::Role::MutableFile> for details.
+#pod
+#pod =cut
 
 with 'Dist::Zilla::Role::MutableFile', 'Dist::Zilla::Role::StubBuild';
 
@@ -45,7 +51,7 @@ Dist::Zilla::File::InMemory - a file that you build entirely in memory
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -56,11 +62,11 @@ See L<Dist::Zilla::Role::MutableFile> for details.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
