@@ -1,13 +1,24 @@
-package Dist::Zilla::MVP::Assembler::Zilla;
-{
-  $Dist::Zilla::MVP::Assembler::Zilla::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::MVP::Assembler::Zilla 6.000; # TRIAL
+# ABSTRACT: Dist::Zilla::MVP::Assembler for the Dist::Zilla object
+
 use Moose;
 extends 'Dist::Zilla::MVP::Assembler';
-# ABSTRACT: Dist::Zilla::MVP::Assembler for the Dist::Zilla object
 
 use namespace::autoclean;
 
+#pod =head1 OVERVIEW
+#pod
+#pod This is a subclass of L<Dist::Zilla::MVP::Assembler> used when assembling the
+#pod Dist::Zilla object.
+#pod
+#pod It has a C<zilla_class> attribute, which is used to determine what class of
+#pod Dist::Zilla object to create.  (This isn't very useful now, but will be in the
+#pod future when minting and building use different subclasses of Dist::Zilla.)
+#pod
+#pod Upon construction, the assembler will create a L<Dist::Zilla::MVP::RootSection>
+#pod as the initial section.
+#pod
+#pod =cut
 
 use MooseX::Types::Perl qw(PackageName);
 use Dist::Zilla::MVP::RootSection;
@@ -25,12 +36,27 @@ has zilla_class => (
   required => 1
 );
 
+#pod =method zilla
+#pod
+#pod This method is a shortcut for retrieving the C<zilla> from the root section.
+#pod If called before that section has been finalized, it will result in an
+#pod exception.
+#pod
+#pod =cut
 
 sub zilla {
   my ($self) = @_;
   $self->sequence->section_named('_')->zilla;
 }
 
+#pod =method register_stash
+#pod
+#pod   $assembler->register_stash($name => $stash_object);
+#pod
+#pod This adds a stash to the assembler's zilla's stash registry -- unless the name
+#pod is already taken, in which case an exception is raised.
+#pod
+#pod =cut
 
 sub register_stash {
   my ($self, $name, $object) = @_;
@@ -56,7 +82,7 @@ Dist::Zilla::MVP::Assembler::Zilla - Dist::Zilla::MVP::Assembler for the Dist::Z
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 OVERVIEW
 
@@ -87,11 +113,11 @@ is already taken, in which case an exception is raised.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
