@@ -1,14 +1,17 @@
-package Dist::Zilla::MVP::Reader::Perl;
-{
-  $Dist::Zilla::MVP::Reader::Perl::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::MVP::Reader::Perl 6.000; # TRIAL
+# ABSTRACT: the reader for dist.pl files
+
 use Moose;
 extends 'Config::MVP::Reader';
 with qw(Config::MVP::Reader::Findable::ByExtension);
-# ABSTRACT: the reader for dist.pl files
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod Dist::Zilla::Config reads in the F<dist.pl> file for a distribution.
+#pod
+#pod =cut
 
 sub default_extension { 'pl' }
 
@@ -60,7 +63,7 @@ Dist::Zilla::MVP::Reader::Perl - the reader for dist.pl files
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -68,11 +71,11 @@ Dist::Zilla::Config reads in the F<dist.pl> file for a distribution.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
