@@ -1,16 +1,21 @@
-package Dist::Zilla::MintingProfile::Default;
-{
-  $Dist::Zilla::MintingProfile::Default::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::MintingProfile::Default 6.000; # TRIAL
 # ABSTRACT: Default minting profile provider
+
 use Moose;
 with 'Dist::Zilla::Role::MintingProfile::ShareDir';
 
 use namespace::autoclean;
 
 use Dist::Zilla::Util;
-use Path::Class;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod Default minting profile provider.
+#pod
+#pod This provider looks first in the F<~/.dzil/profiles/$profile_name> directory,
+#pod if not found it looks among the default profiles shipped with Dist::Zilla.
+#pod
+#pod =cut
 
 around profile_dir => sub {
   my ($orig, $self, $profile_name) = @_;
@@ -20,7 +25,7 @@ around profile_dir => sub {
   # shouldn't look in user's config when testing
   if (!$ENV{DZIL_TESTING}) {
     my $profile_dir = Dist::Zilla::Util->_global_config_root
-                    ->subdir('profiles', $profile_name);
+                    ->child('profiles', $profile_name);
 
     return $profile_dir if -d $profile_dir;
   }
@@ -43,7 +48,7 @@ Dist::Zilla::MintingProfile::Default - Default minting profile provider
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -54,11 +59,11 @@ if not found it looks among the default profiles shipped with Dist::Zilla.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
