@@ -1,16 +1,23 @@
-package Dist::Zilla::Plugin::CPANFile;
-{
-  $Dist::Zilla::Plugin::CPANFile::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Plugin::CPANFile 6.000; # TRIAL
 # ABSTRACT: produce a cpanfile prereqs file
+
 use Moose;
-use Moose::Autobox;
 with 'Dist::Zilla::Role::FileGatherer';
 
 use namespace::autoclean;
 
 use Dist::Zilla::File::FromCode;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugin will add a F<cpanfile> file to the distribution.
+#pod
+#pod =attr filename
+#pod
+#pod If given, parameter allows you to specify an alternate name for the generated
+#pod file.  It defaults, of course, to F<cpanfile>.
+#pod
+#pod =cut
 
 has filename => (
   is  => 'ro',
@@ -81,7 +88,7 @@ Dist::Zilla::Plugin::CPANFile - produce a cpanfile prereqs file
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -96,11 +103,11 @@ file.  It defaults, of course, to F<cpanfile>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
