@@ -1,24 +1,20 @@
-package Dist::Zilla::Plugin::ConfirmRelease;
-{
-  $Dist::Zilla::Plugin::ConfirmRelease::VERSION = '5.003'; # TRIAL
-}
-use Moose;
-with 'Dist::Zilla::Role::BeforeRelease';
+package Dist::Zilla::Plugin::ConfirmRelease 6.000; # TRIAL
 # ABSTRACT: prompt for confirmation before releasing
 
-use namespace::autoclean;
+use Moose;
+with 'Dist::Zilla::Role::BeforeRelease';
 
-use Moose::Autobox;
+use namespace::autoclean;
 
 sub before_release {
   my ($self, $tgz) = @_;
 
   my $releasers = join q{, },
                   map {; $_->plugin_name }
-                  $self->zilla->plugins_with(-Releaser)->flatten;
+                  @{ $self->zilla->plugins_with(-Releaser) };
 
-  my $prompt = "*** Preparing to release $tgz with $releasers ***\n"
-             . "Do you want to continue the release process?";
+  $self->log("*** Preparing to release $tgz with $releasers ***");
+  my $prompt = "Do you want to continue the release process?";
 
   my $default = exists $ENV{DZIL_CONFIRMRELEASE_DEFAULT}
               ? $ENV{DZIL_CONFIRMRELEASE_DEFAULT}
@@ -35,6 +31,16 @@ sub before_release {
 __PACKAGE__->meta->make_immutable;
 1;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugin prompts the author whether or not to continue before releasing
+#pod the distribution to CPAN.  It gives authors a chance to abort before
+#pod they upload.
+#pod
+#pod The default is "no", but you can set the environment variable
+#pod C<DZIL_CONFIRMRELEASE_DEFAULT> to "yes" if you just want to hit enter to
+#pod release.
+
 __END__
 
 =pod
@@ -47,7 +53,7 @@ Dist::Zilla::Plugin::ConfirmRelease - prompt for confirmation before releasing
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -61,11 +67,11 @@ release.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
