@@ -1,19 +1,55 @@
-package Dist::Zilla::Plugin::DistINI;
-{
-  $Dist::Zilla::Plugin::DistINI::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Plugin::DistINI 6.000; # TRIAL
 # ABSTRACT: a plugin to add a dist.ini to newly-minted dists
+
 use Moose;
 with qw(Dist::Zilla::Role::FileGatherer);
 
 use Dist::Zilla::File::FromCode;
 
-use Moose::Autobox 0.10; # for ->each_value
 use MooseX::Types::Moose qw(ArrayRef Str);
-use Path::Tiny;
+use Dist::Zilla::Path;
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugins produces a F<dist.ini> file in a new dist, specifying the required
+#pod core attributes from the dist being minted.
+#pod
+#pod This plugin is dead simple and pretty stupid, but should get better as dist
+#pod minting facilities improve.  For example, it will not specify any plugins.
+#pod
+#pod In the meantime, you may be happier with a F<dist.ini> template.
+#pod
+#pod =attr append_file
+#pod
+#pod This parameter may be a filename in the profile's directory to append to the
+#pod generated F<dist.ini> with things like plugins.  In other words, if your make
+#pod this file, called F<plugins.ini>:
+#pod
+#pod   [@Basic]
+#pod   [NextRelease]
+#pod   [@Git]
+#pod
+#pod ...and your F<profile.ini> includes:
+#pod
+#pod   [DistINI]
+#pod   append_file = plugins.ini
+#pod
+#pod ...then the generated C<dist.ini> in a newly-minted dist will look something
+#pod like this:
+#pod
+#pod   name    = My-New-Dist
+#pod   author  = E. Xavier Ample <example@example.com>
+#pod   license = Perl_5
+#pod   copyright_holder = E. Xavier Ample
+#pod   copyright_year   = 2010
+#pod
+#pod   [@Basic]
+#pod   [NextRelease]
+#pod   [@Git]
+#pod
+#pod =cut
 
 sub mvp_multivalue_args { qw(append_file) }
 
@@ -29,11 +65,12 @@ sub gather_files {
   my $zilla = $self->zilla;
 
   my $postlude = '';
-  $self->append_file->each_value(sub {
-    my $fn = $self->zilla->root->file($_);
+
+  for (@{ $self->append_file }) {
+    my $fn = $self->zilla->root->child($_);
 
     $postlude .= path($fn)->slurp_utf8;
-  });
+  }
 
   my $code = sub {
     my @core_attrs = qw(name authors copyright_holder);
@@ -79,7 +116,7 @@ Dist::Zilla::Plugin::DistINI - a plugin to add a dist.ini to newly-minted dists
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -123,11 +160,11 @@ like this:
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
