@@ -1,13 +1,24 @@
-package Dist::Zilla::Plugin::ExtraTests;
-{
-  $Dist::Zilla::Plugin::ExtraTests::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Plugin::ExtraTests 6.000; # TRIAL
 # ABSTRACT: rewrite ./xt tests to ./t tests with skips
+
 use Moose;
 with 'Dist::Zilla::Role::FileMunger';
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugin rewrites tests found in the following directories:
+#pod
+#pod   ./xt/author  - tests for author testing (env AUTHOR_TESTING is true)
+#pod   ./xt/release - tests for pre-release testers (env RELEASE_TESTING is true)
+#pod   ./xt/smoke   - tests for automated testers (env AUTOMATED_TESTING is true)
+#pod
+#pod The tests are renamed and moved to F<./t>, and they are rewritten to include
+#pod some simple Perl code to skip all included tests if the correct env vars are
+#pod not set.
+#pod
+#pod =cut
 
 sub munge_file {
   my ($self, $file) = @_;
@@ -38,7 +49,7 @@ sub _rewrite_release_test {
 sub _rewrite {
   my ($self, $file, $env, $msg) = @_;
 
-  (my $name = $file->name) =~ s{^xt/([^/]+)/}{t/$1-};
+  my $name = $file->name =~ s{^xt/([^/]+)/}{t/$1-}r;
 
   $file->name($name);
 
@@ -71,7 +82,7 @@ Dist::Zilla::Plugin::ExtraTests - rewrite ./xt tests to ./t tests with skips
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -87,11 +98,11 @@ not set.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
