@@ -1,7 +1,4 @@
-package Dist::Zilla::Plugin::FakeRelease;
-{
-  $Dist::Zilla::Plugin::FakeRelease::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Plugin::FakeRelease 6.000; # TRIAL
 # ABSTRACT: fake plugin to test release
 
 use Moose;
@@ -16,6 +13,8 @@ has user => (
   default  => 'AUTHORID',
 );
 
+sub cpanid { shift->user }
+
 sub release {
   my $self = shift;
 
@@ -32,6 +31,36 @@ sub release {
 __PACKAGE__->meta->make_immutable;
 1;
 
+#pod =head1 SYNOPSIS
+#pod
+#pod     [FakeRelease]
+#pod     user = CPANAUTHORID ; # optional.
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugin is a L<Releaser|Dist::Zilla::Role::Releaser> that does nothing. It
+#pod is directed to plugin authors, who may need a dumb release plugin to test their
+#pod shiny plugin implementing L<BeforeRelease|Dist::Zilla::Role::BeforeRelease>
+#pod and L<AfterRelease|Dist::Zilla::Role::AfterRelease>.
+#pod
+#pod When this plugin does the release, it will just log a message and finish.
+#pod
+#pod If you set the environment variable C<DZIL_FAKERELEASE_FAIL> to a true value,
+#pod the plugin will die instead of doing nothing. This can be useful for
+#pod authors wanting to test reliably that release failed.
+#pod
+#pod You can optionally provide the 'user' parameter, which defaults to 'AUTHORID',
+#pod which will allow things that depend on this metadata
+#pod ( Sometimes provided by L<UploadToCPAN|Dist::Zilla::Plugin::UploadToCPAN> ) to still work.
+#pod ( For example: L<Dist::Zilla::Plugin::Twitter> )
+#pod
+#pod =head1 SEE ALSO
+#pod
+#pod Core Dist::Zilla plugins:
+#pod L<ConfirmRelease|Dist::Zilla::Plugin::ConfirmRelease>,
+#pod L<UploadToCPAN|Dist::Zilla::Plugin::UploadToCPAN>.
+#pod
+
 __END__
 
 =pod
@@ -44,7 +73,7 @@ Dist::Zilla::Plugin::FakeRelease - fake plugin to test release
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 SYNOPSIS
 
@@ -77,11 +106,11 @@ L<UploadToCPAN|Dist::Zilla::Plugin::UploadToCPAN>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
