@@ -1,7 +1,6 @@
-package Dist::Zilla::Plugin::FileFinder::Filter;
-{
-  $Dist::Zilla::Plugin::FileFinder::Filter::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Plugin::FileFinder::Filter 6.000; # TRIAL
+# ABSTRACT: filter matches from other FileFinders
+
 use Moose;
 with(
   'Dist::Zilla::Role::FileFinder',
@@ -9,10 +8,23 @@ with(
     default_finders => [],
   },
 );
-# ABSTRACT: filter matches from other FileFinders
 
 use namespace::autoclean;
 
+#pod =head1 SYNOPSIS
+#pod
+#pod In your F<dist.ini>:
+#pod
+#pod   [FileFinder::Filter / MyFiles]
+#pod   finder = :InstallModules ; find files from :InstallModules
+#pod   finder = :ExecFiles      ; or :ExecFiles
+#pod   skip  = ignore           ; that don't have "ignore" in the path
+#pod
+#pod =head1 CREDITS
+#pod
+#pod This plugin was originally contributed by Christopher J. Madsen.
+#pod
+#pod =cut
 
 use Moose::Util::TypeConstraints;
 use MooseX::Types::Moose qw(ArrayRef RegexpRef Str);
@@ -21,6 +33,17 @@ use MooseX::Types::Moose qw(ArrayRef RegexpRef Str);
   my $type = subtype as ArrayRef[RegexpRef];
   coerce $type, from ArrayRef[Str], via { [map { qr/$_/ } @$_] };
 
+#pod =attr finder
+#pod
+#pod A FileFinder to supply the initial list of files.
+#pod May occur multiple times.
+#pod
+#pod =attr skip
+#pod
+#pod The pathname must I<not> match any of these regular expressions.
+#pod May occur multiple times.
+#pod
+#pod =cut
 
   has skips => (
     is      => 'ro',
@@ -54,6 +77,20 @@ sub find_files {
 __PACKAGE__->meta->make_immutable;
 1;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod FileFinder::Filter is a L<FileFinder|Dist::Zilla::Role::FileFinder> that
+#pod selects files by filtering the selections of other FileFinders.
+#pod
+#pod You specify one or more FileFinders to generate the initial list of
+#pod files.  Any file whose pathname matches any of the C<skip> regexs is
+#pod removed from that list.
+#pod
+#pod =for Pod::Coverage
+#pod mvp_aliases
+#pod mvp_multivalue_args
+#pod find_files
+
 __END__
 
 =pod
@@ -66,7 +103,7 @@ Dist::Zilla::Plugin::FileFinder::Filter - filter matches from other FileFinders
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 SYNOPSIS
 
@@ -108,11 +145,11 @@ find_files
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
