@@ -1,14 +1,11 @@
-package Dist::Zilla::Plugin::FinderCode;
-{
-  $Dist::Zilla::Plugin::FinderCode::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Plugin::FinderCode 6.000; # TRIAL
+# ABSTRACT: a callback-based FileFinder plugin
+
 use Moose;
 with 'Dist::Zilla::Role::FileFinder';
-# ABSTRACT: a callback-based FileFinder plugin
 
 use namespace::autoclean;
 
-use Moose::Autobox;
 use Moose::Util::TypeConstraints;
 
 has code => (
@@ -34,7 +31,7 @@ sub find_files {
 sub _find_via_grep {
   my ($self) = @_;
 
-  my @files = grep { $self->code->($_, $self) } $self->zilla->files->flatten;
+  my @files = grep { $self->code->($_, $self) } @{ $self->zilla->files };
   return \@files;
 }
 
@@ -60,15 +57,15 @@ Dist::Zilla::Plugin::FinderCode - a callback-based FileFinder plugin
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
