@@ -1,10 +1,7 @@
-package Dist::Zilla::Plugin::GenerateFile;
-{
-  $Dist::Zilla::Plugin::GenerateFile::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Plugin::GenerateFile 6.000; # TRIAL
 # ABSTRACT: build a custom file from only the plugin configuration
+
 use Moose;
-use Moose::Autobox;
 with (
   'Dist::Zilla::Role::FileGatherer',
   'Dist::Zilla::Role::TextTemplate',
@@ -14,11 +11,51 @@ use namespace::autoclean;
 
 use Dist::Zilla::File::InMemory;
 
+#pod =head1 SYNOPSIS
+#pod
+#pod In your F<dist.ini>:
+#pod
+#pod   [GenerateFile]
+#pod   filename    = todo/{{ $dist->name }}-master-plan.txt
+#pod   name_is_template = 1
+#pod   content_is_template = 1
+#pod   content = # Outlines the plan for world domination by {{$dist->name}}
+#pod   content =
+#pod   content = Item 1: Think of an idea!
+#pod   content = Item 2: ?
+#pod   content = Item 3: Profit!
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugin adds a file to the distribution.
+#pod
+#pod You can specify the content, as a sequence of lines, in your configuration.
+#pod The specified filename and content might be literals or might be L<Text::Template>
+#pod templates.
+#pod
+#pod =head2 Templating of the content
+#pod
+#pod If you provide C<content_is_template> (or C<is_template>) parameter of C<"1">, the
+#pod content will be run through L<Text::Template>.  The variables C<$plugin> and
+#pod C<$dist> will be provided, set to the [GenerateFile] plugin and the L<Dist::Zilla>
+#pod object respectively.
+#pod
+#pod If you provide a C<name_is_template> parameter of "1", the filename will be run
+#pod through L<Text::Template>.  The variables C<$plugin> and C<$dist> will be
+#pod provided, set to the [GenerateFile] plugin and the L<Dist::Zilla> object
+#pod respectively.
+#pod
+#pod =cut
 
 sub mvp_aliases { +{ is_template => 'content_is_template' } }
 
 sub mvp_multivalue_args { qw(content) }
 
+#pod =attr filename
+#pod
+#pod This attribute names the file you want to generate.  It is required.
+#pod
+#pod =cut
 
 has filename => (
   is  => 'ro',
@@ -26,12 +63,24 @@ has filename => (
   required => 1,
 );
 
+#pod =attr content
+#pod
+#pod The C<content> attribute is an arrayref of lines that will be joined together
+#pod with newlines to form the file content.
+#pod
+#pod =cut
 
 has content => (
   is  => 'ro',
   isa => 'ArrayRef',
 );
 
+#pod =attr content_is_template, is_template
+#pod
+#pod This attribute is a bool indicating whether or not the content should be
+#pod treated as a Text::Template template.  By default, it is false.
+#pod
+#pod =cut
 
 has content_is_template => (
   is  => 'ro',
@@ -39,6 +88,14 @@ has content_is_template => (
   default => 0,
 );
 
+#pod =cut
+#pod
+#pod =attr name_is_template
+#pod
+#pod This attribute is a bool indicating whether or not the filename should be
+#pod treated as a Text::Template template.  By default, it is false.
+#pod
+#pod =cut
 
 has name_is_template => (
   is  => 'ro',
@@ -61,7 +118,7 @@ sub gather_files {
 sub _content {
   my $self = shift;
 
-  my $content = join "\n", $self->content->flatten;
+  my $content = join "\n", @{ $self->content };
   $content .= qq{\n};
 
   if ($self->content_is_template) {
@@ -110,14 +167,14 @@ Dist::Zilla::Plugin::GenerateFile - build a custom file from only the plugin con
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 SYNOPSIS
 
 In your F<dist.ini>:
 
   [GenerateFile]
-  filename    = todo/{{ $dist->name =~ s/::/-/r }}_master-plan.txt
+  filename    = todo/{{ $dist->name }}-master-plan.txt
   name_is_template = 1
   content_is_template = 1
   content = # Outlines the plan for world domination by {{$dist->name}}
@@ -131,19 +188,19 @@ In your F<dist.ini>:
 This plugin adds a file to the distribution.
 
 You can specify the content, as a sequence of lines, in your configuration.
-The specified filename and content might be literals or might be Text::Template
+The specified filename and content might be literals or might be L<Text::Template>
 templates.
 
 =head2 Templating of the content
 
-If you provide C<content_is_template> (or C<is_template>) parameter of "1", the
-content will be run through Text::Template.  The variables C<$plugin> and
-C<$dist> will be provided, set to the GenerateFile plugin and the Dist::Zilla
+If you provide C<content_is_template> (or C<is_template>) parameter of C<"1">, the
+content will be run through L<Text::Template>.  The variables C<$plugin> and
+C<$dist> will be provided, set to the [GenerateFile] plugin and the L<Dist::Zilla>
 object respectively.
 
 If you provide a C<name_is_template> parameter of "1", the filename will be run
-through Text::Template.  The variables C<$plugin> and C<$dist> will be
-provided, set to the GenerateFile plugin and the Dist::Zilla object
+through L<Text::Template>.  The variables C<$plugin> and C<$dist> will be
+provided, set to the [GenerateFile] plugin and the L<Dist::Zilla> object
 respectively.
 
 =head1 ATTRIBUTES
@@ -169,11 +226,11 @@ treated as a Text::Template template.  By default, it is false.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
