@@ -1,14 +1,18 @@
-package Dist::Zilla::Plugin::InlineFiles;
-{
-  $Dist::Zilla::Plugin::InlineFiles::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Plugin::InlineFiles 6.000; # TRIAL
 # ABSTRACT: files in a data section
+
 use Moose;
-use Moose::Autobox;
 with 'Dist::Zilla::Role::FileGatherer';
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugin exists only to be extended, and gathers all files contained in its
+#pod data section and those of its ancestors.  For more information, see
+#pod L<Data::Section|Data::Section>.
+#pod
+#pod =cut
 
 use Sub::Exporter::ForMethods;
 use Data::Section 0.200002 # encoding and bytes
@@ -37,6 +41,15 @@ sub gather_files {
 __PACKAGE__->meta->make_immutable;
 1;
 
+#pod =head1 SEE ALSO
+#pod
+#pod Core Dist::Zilla plugins inheriting from L<InlineFiles>:
+#pod L<MetaTests|Dist::Zilla::Plugin::MetaTests>,
+#pod L<PodCoverageTests|Dist::Zilla::Plugin::PodCoverageTests>,
+#pod L<PodSyntaxTests|Dist::Zilla::Plugin::PodSyntaxTests>.
+#pod
+#pod =cut
+
 __END__
 
 =pod
@@ -49,7 +62,7 @@ Dist::Zilla::Plugin::InlineFiles - files in a data section
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -66,11 +79,11 @@ L<PodSyntaxTests|Dist::Zilla::Plugin::PodSyntaxTests>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
