@@ -1,21 +1,36 @@
-package Dist::Zilla::Plugin::License;
-{
-  $Dist::Zilla::Plugin::License::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Plugin::License 6.000; # TRIAL
 # ABSTRACT: output a LICENSE file
+
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugin adds a F<LICENSE> file containing the full text of the
+#pod distribution's license, as produced by the C<fulltext> method of the
+#pod dist's L<Software::License> object.
+#pod
+#pod =attr filename
+#pod
+#pod This attribute can be used to specify a name other than F<LICENSE> to be used.
+#pod
+#pod =cut
 
 use Dist::Zilla::File::InMemory;
 
+has filename => (
+  is  => 'ro',
+  isa => 'Str',
+  default => 'LICENSE',
+);
+
 sub gather_files {
   my ($self, $arg) = @_;
 
   my $file = Dist::Zilla::File::InMemory->new({
-    name    => 'LICENSE',
+    name    => $self->filename,
     content => $self->zilla->license->fulltext,
   });
 
@@ -26,6 +41,30 @@ sub gather_files {
 __PACKAGE__->meta->make_immutable;
 1;
 
+#pod =head1 SEE ALSO
+#pod
+#pod =over 4
+#pod
+#pod =item *
+#pod
+#pod the C<license> attribute of the L<Dist::Zilla> object to select the license
+#pod to use.
+#pod
+#pod =item *
+#pod
+#pod Dist::Zilla roles:
+#pod L<FileGatherer|Dist::Zilla::Role::FileGatherer>.
+#pod
+#pod =item *
+#pod
+#pod Other modules:
+#pod L<Software::License>,
+#pod L<Software::License::Artistic_2_0>.
+#pod
+#pod =back
+#pod
+#pod =cut
+
 __END__
 
 =pod
@@ -38,7 +77,7 @@ Dist::Zilla::Plugin::License - output a LICENSE file
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -46,6 +85,12 @@ This plugin adds a F<LICENSE> file containing the full text of the
 distribution's license, as produced by the C<fulltext> method of the
 dist's L<Software::License> object.
 
+=head1 ATTRIBUTES
+
+=head2 filename
+
+This attribute can be used to specify a name other than F<LICENSE> to be used.
+
 =head1 SEE ALSO
 
 =over 4
@@ -70,11 +115,11 @@ L<Software::License::Artistic_2_0>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
