@@ -1,15 +1,35 @@
-package Dist::Zilla::Plugin::ManifestSkip;
-{
-  $Dist::Zilla::Plugin::ManifestSkip::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Plugin::ManifestSkip 6.000; # TRIAL
 # ABSTRACT: decline to build files that appear in a MANIFEST.SKIP-like file
+
 use Moose;
 with 'Dist::Zilla::Role::FilePruner';
 
 use namespace::autoclean;
 
-use Moose::Autobox;
-
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugin reads a MANIFEST.SKIP-like file, as used by L<ExtUtils::MakeMaker>
+#pod and L<ExtUtils::Manifest>, and prunes any files that it declares should be
+#pod skipped.
+#pod
+#pod This plugin is included in the L<@Basic|Dist::Zilla::PluginBundle::Basic>
+#pod bundle.
+#pod
+#pod =attr skipfile
+#pod
+#pod This is the name of the file to read for MANIFEST.SKIP-like content.  It
+#pod defaults, unsurprisingly, to F<MANIFEST.SKIP>.
+#pod
+#pod =head1 SEE ALSO
+#pod
+#pod Dist::Zilla core plugins:
+#pod L<@Basic|Dist::Zilla::PluginBundle::Basic>,
+#pod L<PruneCruft|Dist::Zilla::Plugin::PruneCruft>,
+#pod L<PruneFiles|Dist::Zilla::Plugin::PruneFiles>.
+#pod
+#pod Other modules: L<ExtUtils::Manifest>.
+#pod
+#pod =cut
 
 has skipfile => (is => 'ro', required => 1, default => 'MANIFEST.SKIP');
 
@@ -18,7 +38,7 @@ sub prune_files {
   my $files = $self->zilla->files;
 
   my $skipfile_name = $self->skipfile;
-  my ($skipfile) = grep { $_->name eq $skipfile_name } $files->flatten;
+  my ($skipfile) = grep { $_->name eq $skipfile_name } @$files;
   unless (defined $skipfile) {
     $self->log_debug([ 'file %s not found', $skipfile_name ]);
     return;
@@ -43,7 +63,8 @@ sub prune_files {
 
   my $skip = ExtUtils::Manifest::maniskip($skipfile_name);
 
-  for my $file ($files->flatten) {
+  # Copy list (break reference) so we can mutate.
+  for my $file ((), @{ $files }) {
     next unless $skip->($file->name);
 
     $self->log_debug([ 'pruning %s', $file->name ]);
@@ -69,7 +90,7 @@ Dist::Zilla::Plugin::ManifestSkip - decline to build files that appear in a MANI
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -98,11 +119,11 @@ Other modules: L<ExtUtils::Manifest>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
