@@ -1,13 +1,24 @@
-package Dist::Zilla::Plugin::MetaConfig;
-{
-  $Dist::Zilla::Plugin::MetaConfig::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Plugin::MetaConfig 6.000; # TRIAL
 # ABSTRACT: summarize Dist::Zilla configuration into distmeta
+
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugin adds a top-level C<x_Dist_Zilla> key to the
+#pod L<distmeta|Dist::Zilla/distmeta> for the distribution.  It describe the
+#pod Dist::Zilla version used as well as all the plugins used.  Each plugin's name,
+#pod package, and version will be included.  Plugins may augment their
+#pod implementation of the L<Dist::Zilla::Role::ConfigDumper> role methods to add
+#pod more data to this dump.
+#pod
+#pod More information may be added to the top-level of this metadata as time goes
+#pod on.
+#pod
+#pod =cut
 
 sub metadata {
   my ($self) = @_;
@@ -45,6 +56,12 @@ sub metadata {
 __PACKAGE__->meta->make_immutable;
 1;
 
+#pod =head1 SEE ALSO
+#pod
+#pod Dist::Zilla roles: L<MetaProvider|Dist::Zilla::Role::MetaProvider>.
+#pod
+#pod =cut
+
 __END__
 
 =pod
@@ -57,7 +74,7 @@ Dist::Zilla::Plugin::MetaConfig - summarize Dist::Zilla configuration into distm
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -77,11 +94,11 @@ Dist::Zilla roles: L<MetaProvider|Dist::Zilla::Role::MetaProvider>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
