@@ -1,16 +1,24 @@
-package Dist::Zilla::Plugin::MetaJSON;
-{
-  $Dist::Zilla::Plugin::MetaJSON::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Plugin::MetaJSON 6.000; # TRIAL
 # ABSTRACT: produce a META.json
+
 use Moose;
-use Moose::Autobox;
 with 'Dist::Zilla::Role::FileGatherer';
 
 use namespace::autoclean;
 
-use Dist::Zilla::File::FromCode;
-
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugin will add a F<META.json> file to the distribution.
+#pod
+#pod This file is meant to replace the old-style F<META.yml>.  For more information
+#pod on this file, see L<Module::Build::API> and L<CPAN::Meta>.
+#pod
+#pod =attr filename
+#pod
+#pod If given, parameter allows you to specify an alternate name for the generated
+#pod file.  It defaults, of course, to F<META.json>.
+#pod
+#pod =cut
 
 has filename => (
   is  => 'ro',
@@ -18,6 +26,15 @@ has filename => (
   default => 'META.json',
 );
 
+#pod =attr version
+#pod
+#pod This parameter lets you pick what version of the spec to use when generating
+#pod the output.  It defaults to 2 at present, but may be updated to new specs as
+#pod they are released and adopted.
+#pod
+#pod If you want a fixed version, specify it.
+#pod
+#pod =cut
 
 has version => (
   is  => 'ro',
@@ -30,8 +47,8 @@ sub gather_files {
 
   my $zilla = $self->zilla;
 
-  require JSON;
-  JSON->VERSION(2);
+  require JSON::MaybeXS;
+  require Dist::Zilla::File::FromCode;
   require CPAN::Meta::Converter;
   CPAN::Meta::Converter->VERSION(2.101550); # improved downconversion
   require CPAN::Meta::Validator;
@@ -39,10 +56,8 @@ sub gather_files {
 
   my $file  = Dist::Zilla::File::FromCode->new({
     name => $self->filename,
-    # RJBS and XDG didn't 100% agree on this, it's probably fine until somebody
-    # comes up with a really good argument to change it (or to remove this
-    # comment, settling the argument). -- rjbs, 2013-10-19
-    code_return_type => 'bytes',
+    encoding => 'ascii',
+    code_return_type => 'text',
     code => sub {
       my $distmeta  = $zilla->distmeta;
 
@@ -57,7 +72,10 @@ sub gather_files {
       my $converter = CPAN::Meta::Converter->new($distmeta);
       my $output    = $converter->convert(version => $self->version);
 
-      JSON->new->ascii(1)->canonical(1)->pretty->encode($output)
+      # note utf8 => 1 is *not* used - so unicode characters remain as-is in
+      # the resulting json string, and therefore an encoding must be used when
+      # the file is written to disk.
+      JSON::MaybeXS->new(canonical => 1, pretty => 1, ascii => 1)->encode($output)
       . "\n";
     },
   });
@@ -69,6 +87,21 @@ sub gather_files {
 __PACKAGE__->meta->make_immutable;
 1;
 
+#pod =head1 SEE ALSO
+#pod
+#pod Core Dist::Zilla plugins:
+#pod L<@Basic|Dist::Zilla::PluginBundle::Basic>,
+#pod L<Manifest|Dist::Zilla::Plugin::Manifest>.
+#pod
+#pod Dist::Zilla roles:
+#pod L<FileGatherer|Dist::Zilla::Role::FileGatherer>.
+#pod
+#pod Other modules:
+#pod L<CPAN::Meta>,
+#pod L<CPAN::Meta::Spec>, L<JSON::MaybeXS>.
+#pod
+#pod =cut
+
 __END__
 
 =pod
@@ -81,7 +114,7 @@ Dist::Zilla::Plugin::MetaJSON - produce a META.json
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -116,15 +149,15 @@ L<FileGatherer|Dist::Zilla::Role::FileGatherer>.
 
 Other modules:
 L<CPAN::Meta>,
-L<CPAN::Meta::Spec>, L<JSON>.
+L<CPAN::Meta::Spec>, L<JSON::MaybeXS>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
