@@ -1,7 +1,4 @@
-package Dist::Zilla::Plugin::MetaNoIndex;
-{
-  $Dist::Zilla::Plugin::MetaNoIndex::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Plugin::MetaNoIndex 6.000; # TRIAL
 # ABSTRACT: Stop CPAN from indexing stuff
 
 use Moose;
@@ -9,6 +6,34 @@ with 'Dist::Zilla::Role::MetaProvider';
 
 use namespace::autoclean;
 
+#pod =encoding utf8
+#pod
+#pod =head1 SYNOPSIS
+#pod
+#pod In your F<dist.ini>:
+#pod
+#pod   [MetaNoIndex]
+#pod
+#pod   directory = t/author
+#pod   directory = examples
+#pod
+#pod   file = lib/Foo.pm
+#pod
+#pod   package = My::Module
+#pod
+#pod   namespace = My::Module
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugin allows you to prevent PAUSE/CPAN from indexing files you don't
+#pod want indexed. This is useful if you build test classes or example classes
+#pod that are used for those purposes only, and are not part of the distribution.
+#pod It does this by adding a C<no_index> block to your F<META.json> (or
+#pod F<META.yml>) file in your distribution.
+#pod
+#pod =for Pod::Coverage mvp_aliases mvp_multivalue_args
+#pod
+#pod =cut
 
 my %ATTR_ALIAS = (
   directories => [ qw(directory dir folder) ],
@@ -29,6 +54,34 @@ sub mvp_aliases {
 
 sub mvp_multivalue_args { return keys %ATTR_ALIAS }
 
+#pod =attr directories
+#pod
+#pod Exclude folders and everything in them, for example: F<author.t>
+#pod
+#pod Aliases: C<folder>, C<dir>, C<directory>
+#pod
+#pod =attr files
+#pod
+#pod Exclude a specific file, for example: F<lib/Foo.pm>
+#pod
+#pod Alias: C<file>
+#pod
+#pod =attr packages
+#pod
+#pod Exclude by package name, for example: C<My::Package>
+#pod
+#pod Aliases: C<class>, C<module>, C<package>
+#pod
+#pod =attr namespaces
+#pod
+#pod Exclude everything under a specific namespace, for example: C<My::Package>
+#pod
+#pod Alias: C<namespace>
+#pod
+#pod B<NOTE:> This will not exclude the package C<My::Package>, only everything
+#pod under it like C<My::Package::Foo>.
+#pod
+#pod =cut
 
 for my $attr (keys %ATTR_ALIAS) {
   has $attr => (
@@ -39,12 +92,17 @@ for my $attr (keys %ATTR_ALIAS) {
   );
 }
 
+#pod =method metadata
+#pod
+#pod Returns a reference to a hash containing the distribution's no_index metadata.
+#pod
+#pod =cut
 
 sub metadata {
   my $self = shift;
   return {
     no_index => {
-      map  {; my $reader = $_->[0];  ($_->[1] => $self->$reader) }
+      map  {; my $reader = $_->[0];  ($_->[1] => [ sort @{ $self->$reader } ]) }
       grep {; my $pred   = "_has_$_->[0]"; $self->$pred }
       map  {; [ $_ => $ATTR_ALIAS{$_}[0] ] }
       keys %ATTR_ALIAS
@@ -55,6 +113,12 @@ sub metadata {
 __PACKAGE__->meta->make_immutable;
 1;
 
+#pod =head1 SEE ALSO
+#pod
+#pod Dist::Zilla roles: L<MetaProvider|Dist::Zilla::Role::MetaProvider>.
+#pod
+#pod =cut
+
 __END__
 
 =pod
@@ -67,7 +131,7 @@ Dist::Zilla::Plugin::MetaNoIndex - Stop CPAN from indexing stuff
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 SYNOPSIS
 
@@ -135,11 +199,11 @@ Dist::Zilla roles: L<MetaProvider|Dist::Zilla::Role::MetaProvider>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
