@@ -1,14 +1,24 @@
-package Dist::Zilla::Plugin::MetaResources;
-{
-  $Dist::Zilla::Plugin::MetaResources::VERSION = '5.003'; # TRIAL
-}
-
+package Dist::Zilla::Plugin::MetaResources 6.000; # TRIAL
 # ABSTRACT: provide arbitrary "resources" for distribution metadata
+
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider';
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugin adds resources entries to the distribution's metadata.
+#pod
+#pod   [MetaResources]
+#pod   homepage          = http://example.com/~dude/project.asp
+#pod   bugtracker.web    = https://rt.cpan.org/Public/Dist/Display.html?Name=Project
+#pod   bugtracker.mailto = bug-Project@rt.cpan.org
+#pod   repository.url    = git://github.com/dude/project.git
+#pod   repository.web    = http://github.com/dude/project
+#pod   repository.type   = git
+#pod
+#pod =cut
 
 has resources => (
   is       => 'ro',
@@ -16,9 +26,12 @@ has resources => (
   required => 1,
 );
 
-sub BUILDARGS {
+around BUILDARGS => sub {
+  my $orig = shift;
   my ($class, @arg) = @_;
-  my %copy = ref $arg[0] ? %{ $arg[0] } : @arg;
+
+  my $args = $class->$orig(@arg);
+  my %copy = %{ $args };
 
   my $zilla = delete $copy{zilla};
   my $name  = delete $copy{plugin_name};
@@ -49,7 +62,7 @@ sub BUILDARGS {
     plugin_name => $name,
     resources   => \%copy,
   };
-}
+};
 
 sub metadata {
   my ($self) = @_;
@@ -60,6 +73,14 @@ sub metadata {
 __PACKAGE__->meta->make_immutable;
 1;
 
+#pod =head1 SEE ALSO
+#pod
+#pod Dist::Zilla roles: L<MetaProvider|Dist::Zilla::Role::MetaProvider>.
+#pod
+#pod Dist::Zilla plugins on the CPAN: L<GithubMeta|Dist::Zilla::Plugin::GithubMeta>.
+#pod
+#pod =cut
+
 __END__
 
 =pod
@@ -72,7 +93,7 @@ Dist::Zilla::Plugin::MetaResources - provide arbitrary "resources" for distribut
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -80,8 +101,8 @@ This plugin adds resources entries to the distribution's metadata.
 
   [MetaResources]
   homepage          = http://example.com/~dude/project.asp
-  bugtracker.web    = http://rt.cpan.org/NoAuth/Bugs.html?Dist=Project
-  bugtracker.mailto = bug-project@rt.cpan.org
+  bugtracker.web    = https://rt.cpan.org/Public/Dist/Display.html?Name=Project
+  bugtracker.mailto = bug-Project@rt.cpan.org
   repository.url    = git://github.com/dude/project.git
   repository.web    = http://github.com/dude/project
   repository.type   = git
@@ -94,11 +115,11 @@ Dist::Zilla plugins on the CPAN: L<GithubMeta|Dist::Zilla::Plugin::GithubMeta>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
