@@ -1,15 +1,24 @@
-package Dist::Zilla::Plugin::MetaYAML;
-{
-  $Dist::Zilla::Plugin::MetaYAML::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Plugin::MetaYAML 6.000; # TRIAL
 # ABSTRACT: produce a META.yml
+
 use Moose;
-use Moose::Autobox;
 with 'Dist::Zilla::Role::FileGatherer';
 
 use Try::Tiny;
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugin will add a F<META.yml> file to the distribution.
+#pod
+#pod For more information on this file, see L<Module::Build::API> and L<CPAN::Meta>.
+#pod
+#pod =attr filename
+#pod
+#pod If given, parameter allows you to specify an alternate name for the generated
+#pod file.  It defaults, of course, to F<META.yml>.
+#pod
+#pod =cut
 
 has filename => (
   is  => 'ro',
@@ -17,6 +26,18 @@ has filename => (
   default => 'META.yml',
 );
 
+#pod =attr version
+#pod
+#pod This parameter lets you pick what version of the spec to use when generating
+#pod the output.  It defaults to 1.4, the most commonly supported version at
+#pod present.
+#pod
+#pod B<This may change without notice in the future.>
+#pod
+#pod Once version 2 of the META file spec is more widely supported, this may default
+#pod to 2.
+#pod
+#pod =cut
 
 has version => (
   is  => 'ro',
@@ -69,6 +90,21 @@ sub gather_files {
 __PACKAGE__->meta->make_immutable;
 1;
 
+#pod =head1 SEE ALSO
+#pod
+#pod Core Dist::Zilla plugins:
+#pod L<@Basic|Dist::Zilla::PluginBundle::Basic>,
+#pod L<Manifest|Dist::Zilla::Plugin::Manifest>.
+#pod
+#pod Dist::Zilla roles:
+#pod L<FileGatherer|Dist::Zilla::Role::FileGatherer>.
+#pod
+#pod Other modules:
+#pod L<CPAN::Meta>,
+#pod L<CPAN::Meta::Spec>, L<YAML>.
+#pod
+#pod =cut
+
 __END__
 
 =pod
@@ -81,7 +117,7 @@ Dist::Zilla::Plugin::MetaYAML - produce a META.yml
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -122,11 +158,11 @@ L<CPAN::Meta::Spec>, L<YAML>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
