@@ -1,14 +1,19 @@
-package Dist::Zilla::Plugin::ModuleShareDirs;
-{
-  $Dist::Zilla::Plugin::ModuleShareDirs::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Plugin::ModuleShareDirs 6.000; # TRIAL
 # ABSTRACT: install a directory's contents as module-based "ShareDir" content
+
 use Moose;
 
 use namespace::autoclean;
 
-use Moose::Autobox;
-
+#pod =head1 SYNOPSIS
+#pod
+#pod In your F<dist.ini>:
+#pod
+#pod   [ModuleShareDirs]
+#pod   Foo::Bar = shares/foo_bar
+#pod   Foo::Baz = shares/foo_baz
+#pod
+#pod =cut
 
 has _module_map => (
   is   => 'ro',
@@ -23,10 +28,9 @@ sub find_files {
 
   for my $mod ( keys %$modmap ) {
     my $dir = $modmap->{$mod};
-    my $mod_files = $self->zilla->files->grep(
-      sub { index($_->name, "$dir/") == 0 }
-    );
-    push @files, @$mod_files;
+    my @mod_files = grep { index($_->name, "$dir/") == 0 }
+      @{ $self->zilla->files };
+    push @files, @mod_files;
   }
 
   return \@files;
@@ -40,9 +44,12 @@ sub share_dir_map {
   return { module => $modmap };
 }
 
-sub BUILDARGS {
+around BUILDARGS => sub {
+  my $orig = shift;
   my ($class, @arg) = @_;
-  my %copy = ref $arg[0] ? %{$arg[0]} : @arg;
+
+  my $args = $class->$orig(@arg);
+  my %copy = %{ $args };
 
   my $zilla = delete $copy{zilla};
   my $name  = delete $copy{plugin_name};
@@ -52,7 +59,7 @@ sub BUILDARGS {
     plugin_name => $name,
     _module_map => \%copy,
   }
-}
+};
 
 with 'Dist::Zilla::Role::ShareDir';
 __PACKAGE__->meta->make_immutable;
@@ -70,7 +77,7 @@ Dist::Zilla::Plugin::ModuleShareDirs - install a directory's contents as module-
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 SYNOPSIS
 
@@ -82,11 +89,11 @@ In your F<dist.ini>:
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
