@@ -1,8 +1,6 @@
-package Dist::Zilla::Plugin::PkgDist;
-{
-  $Dist::Zilla::Plugin::PkgDist::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Plugin::PkgDist 6.000; # TRIAL
 # ABSTRACT: add a $DIST to your packages
+
 use Moose;
 with(
   'Dist::Zilla::Role::FileMunger',
@@ -14,8 +12,23 @@ with(
 
 use namespace::autoclean;
 
-use PPI;
-
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugin will add a line like the following to each package in each Perl
+#pod module or program (more or less) within the distribution:
+#pod
+#pod   { our $DIST = 'My-CPAN-Dist'; } # where 'My-CPAN-Dist' is your dist name
+#pod
+#pod It will skip any package declaration that includes a newline between the
+#pod C<package> keyword and the package name, like:
+#pod
+#pod   package
+#pod     Foo::Bar;
+#pod
+#pod This sort of declaration is also ignored by the CPAN toolchain, and is
+#pod typically used when doing monkey patching or other tricky things.
+#pod
+#pod =cut
 
 sub munge_files {
   my ($self) = @_;
@@ -42,13 +55,13 @@ sub munge_perl {
 
   my $document = $self->ppi_document_for_file($file);
 
+  return unless my $package_stmts = $document->find('PPI::Statement::Package');
+
   if ($self->document_assigns_to_variable($document, '$DIST')) {
     $self->log([ 'skipping %s: assigns to $DIST', $file->name ]);
     return;
   }
 
-  return unless my $package_stmts = $document->find('PPI::Statement::Package');
-
   my %seen_pkg;
 
   for my $stmt (@$package_stmts) {
@@ -78,12 +91,17 @@ sub munge_perl {
       $file->name,
     ]);
 
+    # the extra whitespace element ensures we don't swallow up any blanks
+    # lines after 'package ...' in the source file that PkgVersion warns about
+    # if it's missing.
     Carp::carp('error inserting $DIST in ' . $file->name)
-      unless $stmt->insert_after($children[0]->clone)
+      unless $stmt->add_element( PPI::Token::Whitespace->new("\n") )
+      and    $stmt->insert_after($children[0]->clone)
       and    $stmt->insert_after( PPI::Token::Whitespace->new("\n") );
   }
 
-  $self->save_ppi_document_to_file($document, $file);
+  # the document is no longer correct; it must be reparsed before it can be used again
+  $file->encoded_content($document->serialize);
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -101,7 +119,7 @@ Dist::Zilla::Plugin::PkgDist - add a $DIST to your packages
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -121,11 +139,11 @@ typically used when doing monkey patching or other tricky things.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
