@@ -1,8 +1,6 @@
-package Dist::Zilla::Plugin::PodVersion;
-{
-  $Dist::Zilla::Plugin::PodVersion::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Plugin::PodVersion 6.000; # TRIAL
 # ABSTRACT: add a VERSION head1 to each Perl document
+
 use Moose;
 with(
   'Dist::Zilla::Role::FileMunger',
@@ -13,6 +11,14 @@ with(
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugin adds a C<=head1 VERSION> section to most perl files in the
+#pod distribution, indicating the version of the dist being built.  This section is
+#pod added after C<=head1 NAME>.  If there is no such section, the version section
+#pod will not be added.
+#pod
+#pod =cut
 
 sub munge_files {
   my ($self) = @_;
@@ -31,8 +37,9 @@ sub munge_pod {
 
   my @content = split /\n/, $file->content;
 
-  require List::MoreUtils;
-  if (List::MoreUtils::any(sub { $_ =~ /^=head1 VERSION\b/ }, @content)) {
+  require List::Util;
+  List::Util->VERSION('1.33');
+  if (List::Util::any(sub { $_ =~ /^=head1 VERSION\b/ }, @content)) {
     $self->log($file->name . ' already has a VERSION section in POD');
     return;
   }
@@ -43,7 +50,7 @@ sub munge_pod {
     $_++; # move past the =head1 line itself
     $_++ while $content[$_] =~ /^\s*$/;
 
-    $_++; # move past the line with the abstract
+    $_++ while $content[$_] !~ /^\s*$/; # move past the abstract
     $_++ while $content[$_] =~ /^\s*$/;
 
     splice @content, $_ - 1, 0, (
@@ -70,6 +77,15 @@ sub munge_pod {
 __PACKAGE__->meta->make_immutable;
 1;
 
+#pod =head1 SEE ALSO
+#pod
+#pod Core Dist::Zilla plugins:
+#pod L<PkgVersion|Dist::Zilla::Plugin::PkgVersion>,
+#pod L<AutoVersion|Dist::Zilla::Plugin::AutoVersion>,
+#pod L<NextRelease|Dist::Zilla::Plugin::NextRelease>.
+#pod
+#pod =cut
+
 __END__
 
 =pod
@@ -82,7 +98,7 @@ Dist::Zilla::Plugin::PodVersion - add a VERSION head1 to each Perl document
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -100,11 +116,11 @@ L<NextRelease|Dist::Zilla::Plugin::NextRelease>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
