@@ -1,18 +1,32 @@
-package Dist::Zilla::Plugin::RemovePrereqs;
-{
-  $Dist::Zilla::Plugin::RemovePrereqs::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Plugin::RemovePrereqs 6.000; # TRIAL
 # ABSTRACT: a plugin to remove gathered prereqs
+
 use Moose;
 with 'Dist::Zilla::Role::PrereqSource';
 
 use namespace::autoclean;
 
-use Moose::Autobox;
-
 use MooseX::Types::Moose qw(ArrayRef);
 use MooseX::Types::Perl  qw(ModuleName);
 
+#pod =head1 SYNOPSIS
+#pod
+#pod In your F<dist.ini>:
+#pod
+#pod   [RemovePrereqs]
+#pod   remove = Foo::Bar
+#pod   remove = MRO::Compat
+#pod
+#pod This will remove any prerequisite of any type from any prereq phase.  This is
+#pod useful for eliminating incorrectly detected prereqs.
+#pod
+#pod =head1 SEE ALSO
+#pod
+#pod Dist::Zilla plugins:
+#pod L<Prereqs|Dist::Zilla::Plugin::Prereqs>,
+#pod L<AutoPrereqs|Dist::Zilla::Plugin::AutoPrereqs>.
+#pod
+#pod =cut
 
 sub mvp_multivalue_args { qw(modules_to_remove) }
 
@@ -31,7 +45,7 @@ around dump_config => sub {
   my $config = $self->$orig;
 
   my $this_config = {
-    modules_to_remove  => $self->modules_to_remove,
+    modules_to_remove  => [ sort @{ $self->modules_to_remove } ],
   };
 
   $config->{'' . __PACKAGE__} = $this_config;
@@ -49,7 +63,7 @@ sub register_prereqs {
 
   for my $p (@phases) {
     for my $t (@types) {
-      for my $m ($self->modules_to_remove->flatten) {
+      for my $m (@{ $self->modules_to_remove }) {
         $prereqs->requirements_for($p, $t)->clear_requirement($m);
       }
     }
@@ -71,7 +85,7 @@ Dist::Zilla::Plugin::RemovePrereqs - a plugin to remove gathered prereqs
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 SYNOPSIS
 
@@ -92,11 +106,11 @@ L<AutoPrereqs|Dist::Zilla::Plugin::AutoPrereqs>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
