@@ -1,14 +1,20 @@
-package Dist::Zilla::Plugin::ShareDir;
-{
-  $Dist::Zilla::Plugin::ShareDir::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Plugin::ShareDir 6.000; # TRIAL
 # ABSTRACT: install a directory's contents as "ShareDir" content
+
 use Moose;
 
 use namespace::autoclean;
 
-use Moose::Autobox;
-
+#pod =head1 SYNOPSIS
+#pod
+#pod In your F<dist.ini>:
+#pod
+#pod   [ShareDir]
+#pod   dir = share
+#pod
+#pod If no C<dir> is provided, the default is F<share>.
+#pod
+#pod =cut
 
 has dir => (
   is   => 'ro',
@@ -20,7 +26,10 @@ sub find_files {
   my ($self) = @_;
 
   my $dir = $self->dir;
-  my $files = $self->zilla->files->grep(sub { index($_->name, "$dir/") == 0 });
+  my $files = [
+    grep { index($_->name, "$dir/") == 0 }
+      @{ $self->zilla->files }
+  ];
 }
 
 sub share_dir_map {
@@ -47,7 +56,7 @@ Dist::Zilla::Plugin::ShareDir - install a directory's contents as "ShareDir" con
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 SYNOPSIS
 
@@ -56,15 +65,15 @@ In your F<dist.ini>:
   [ShareDir]
   dir = share
 
-  If no C<dir> is provided, the default is F<share>.
+If no C<dir> is provided, the default is F<share>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
