@@ -1,12 +1,10 @@
-package Dist::Zilla::Plugin::TemplateModule;
-{
-  $Dist::Zilla::Plugin::TemplateModule::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Plugin::TemplateModule 6.000; # TRIAL
 # ABSTRACT: a simple module-from-template plugin
+
 use Moose;
 with qw(Dist::Zilla::Role::ModuleMaker Dist::Zilla::Role::TextTemplate);
 
-use Path::Tiny;
+use Dist::Zilla::Path;
 
 use namespace::autoclean;
 
@@ -18,6 +16,48 @@ use Data::Section 0.200002 # encoding and bytes
   '-setup';
 use Dist::Zilla::File::InMemory;
 
+#pod =head1 MINTING CONFIGURATION
+#pod
+#pod This module is part of the standard configuration of the default L<Dist::Zilla>
+#pod Minting Profile, and all profiles that don't set a custom ':DefaultModuleMaker'
+#pod so you don't need to normally do anything to configure it.
+#pod
+#pod   dzil new Some::Module
+#pod   # creates ./Some-Module/*
+#pod   # creates ./Some-Module/lib/Some/Module.pm
+#pod
+#pod However, for those who wish to configure this ( or any subclasses ) this is
+#pod presently required:
+#pod
+#pod   [TemplateModule / :DefaultModuleMaker]
+#pod   ; template  = SomeFile.pm
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This is a L<ModuleMaker|Dist::Zilla::Role::ModuleMaker> used for creating new
+#pod Perl modules files when minting a new dist with C<dzil new>.  It uses
+#pod L<Text::Template> (via L<Dist::Zilla::Role::TextTemplate>) to render a template
+#pod into a Perl module.  The template is given two variables for use in rendering:
+#pod C<$name>, the module name; and C<$dist>, the Dist::Zilla object.  The module is
+#pod always created as a file under F<./lib>.
+#pod
+#pod By default, the template looks something like this:
+#pod
+#pod   use strict;
+#pod   use warnings;
+#pod   package {{ $name }};
+#pod
+#pod   1;
+#pod
+#pod =attr template
+#pod
+#pod The C<template> parameter may be given to the plugin to provide a different
+#pod filename, absolute or relative to the build/profile directory.
+#pod
+#pod If this parameter is not specified, this module will use the boilerplate module
+#pod template included in this module.
+#pod
+#pod =cut
 
 has template => (
   is  => 'ro',
@@ -44,7 +84,7 @@ sub make_module {
     },
   );
 
-  (my $filename = $arg->{name}) =~ s{::}{/}g;
+  my $filename = $arg->{name} =~ s{::}{/}gr;
 
   my $file = Dist::Zilla::File::InMemory->new({
     name    => "lib/$filename.pm",
@@ -67,7 +107,7 @@ Dist::Zilla::Plugin::TemplateModule - a simple module-from-template plugin
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -114,11 +154,11 @@ presently required:
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
