@@ -1,8 +1,6 @@
-package Dist::Zilla::PluginBundle::Basic;
-{
-  $Dist::Zilla::PluginBundle::Basic::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::PluginBundle::Basic 6.000; # TRIAL
 # ABSTRACT: the basic plugins to maintain and release CPAN dists
+
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -34,6 +32,40 @@ sub configure {
 __PACKAGE__->meta->make_immutable;
 1;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This plugin is meant to be a basic "first step" bundle for using Dist::Zilla.
+#pod It won't munge any of your code, but will generate a F<Makefile.PL> and allows
+#pod easy, reliable releasing of distributions.
+#pod
+#pod It includes the following plugins with their default configuration:
+#pod
+#pod =for :list
+#pod * L<Dist::Zilla::Plugin::GatherDir>
+#pod * L<Dist::Zilla::Plugin::PruneCruft>
+#pod * L<Dist::Zilla::Plugin::ManifestSkip>
+#pod * L<Dist::Zilla::Plugin::MetaYAML>
+#pod * L<Dist::Zilla::Plugin::License>
+#pod * L<Dist::Zilla::Plugin::Readme>
+#pod * L<Dist::Zilla::Plugin::ExtraTests>
+#pod * L<Dist::Zilla::Plugin::ExecDir>
+#pod * L<Dist::Zilla::Plugin::ShareDir>
+#pod * L<Dist::Zilla::Plugin::MakeMaker>
+#pod * L<Dist::Zilla::Plugin::Manifest>
+#pod * L<Dist::Zilla::Plugin::TestRelease>
+#pod * L<Dist::Zilla::Plugin::ConfirmRelease>
+#pod * L<Dist::Zilla::Plugin::UploadToCPAN>
+#pod
+#pod =head1 SEE ALSO
+#pod
+#pod Core Dist::Zilla plugins: L<@Filter|Dist::Zilla::PluginBundle::Filter>.
+#pod
+#pod Dist::Zilla roles:
+#pod L<PluginBundle|Dist::Zilla::Role::PluginBundle>,
+#pod L<PluginBundle::Easy|Dist::Zilla::Role::PluginBundle::Easy>.
+#pod
+#pod =cut
+
 __END__
 
 =pod
@@ -46,7 +78,7 @@ Dist::Zilla::PluginBundle::Basic - the basic plugins to maintain and release CPA
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -126,11 +158,11 @@ L<PluginBundle::Easy|Dist::Zilla::Role::PluginBundle::Easy>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
