@@ -1,8 +1,6 @@
-package Dist::Zilla::PluginBundle::Classic;
-{
-  $Dist::Zilla::PluginBundle::Classic::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::PluginBundle::Classic 6.000; # TRIAL
 # ABSTRACT: the classic (old) default configuration for Dist::Zilla
+
 use Moose;
 with 'Dist::Zilla::Role::PluginBundle::Easy';
 
@@ -37,6 +35,42 @@ sub configure {
 __PACKAGE__->meta->make_immutable;
 1;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This bundle is more or less the original configuration bundled with
+#pod Dist::Zilla.  More than likely, you'd rather be using
+#pod L<@Basic|Dist::Zilla::PluginBundle::Basic> or a more complex bundle.  This one
+#pod will muck around with your code by adding C<$VERSION> declarations and will
+#pod mess with you Pod by adding a C<=head1 VERSION> section, but it won't get you a
+#pod lot of more useful features like autoversioning, autoprereqs, or Pod::Weaver.
+#pod
+#pod It includes the following plugins with their default configuration:
+#pod
+#pod =for :list
+#pod * L<Dist::Zilla::Plugin::GatherDir>
+#pod * L<Dist::Zilla::Plugin::PruneCruft>
+#pod * L<Dist::Zilla::Plugin::ManifestSkip>
+#pod * L<Dist::Zilla::Plugin::MetaYAML>
+#pod * L<Dist::Zilla::Plugin::License>
+#pod * L<Dist::Zilla::Plugin::Readme>
+#pod * L<Dist::Zilla::Plugin::PkgVersion>
+#pod * L<Dist::Zilla::Plugin::PodVersion>
+#pod * L<Dist::Zilla::Plugin::PodCoverageTests>
+#pod * L<Dist::Zilla::Plugin::PodSyntaxTests>
+#pod * L<Dist::Zilla::Plugin::ExtraTests>
+#pod * L<Dist::Zilla::Plugin::ExecDir>
+#pod * L<Dist::Zilla::Plugin::ShareDir>
+#pod * L<Dist::Zilla::Plugin::MakeMaker>
+#pod * L<Dist::Zilla::Plugin::Manifest>
+#pod * L<Dist::Zilla::Plugin::ConfirmRelease>
+#pod * L<Dist::Zilla::Plugin::UploadToCPAN>
+#pod
+#pod =head1 SEE ALSO
+#pod
+#pod L<@Basic|Dist::Zilla::PluginBundle::Basic>
+#pod
+#pod =cut
+
 __END__
 
 =pod
@@ -49,7 +83,7 @@ Dist::Zilla::PluginBundle::Classic - the classic (old) default configuration for
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -140,11 +174,11 @@ L<@Basic|Dist::Zilla::PluginBundle::Basic>
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
