@@ -1,15 +1,11 @@
-package Dist::Zilla::PluginBundle::FakeClassic;
-{
-  $Dist::Zilla::PluginBundle::FakeClassic::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::PluginBundle::FakeClassic 6.000; # TRIAL
 # ABSTRACT: build something more or less like a "classic" CPAN dist
+
 use Moose;
 extends 'Dist::Zilla::PluginBundle::Classic';
 
 use namespace::autoclean;
 
-use Moose::Autobox;
-
 around bundle_config => sub {
   my ($orig, $self, $arg) = @_;
 
@@ -44,15 +40,15 @@ Dist::Zilla::PluginBundle::FakeClassic - build something more or less like a "cl
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
