@@ -1,19 +1,37 @@
-package Dist::Zilla::Prereqs;
-{
-  $Dist::Zilla::Prereqs::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Prereqs 6.000; # TRIAL
 # ABSTRACT: the prerequisites of a Dist::Zilla distribution
+
 use Moose;
-use Moose::Autobox;
 use MooseX::Types::Moose qw(Bool HashRef);
 
 use CPAN::Meta::Prereqs 2.120630; # add_string_requirement
-use Path::Class ();
 use String::RewritePrefix;
 use CPAN::Meta::Requirements 2.121; # requirements_for_module
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod Dist::Zilla::Prereqs is a subcomponent of Dist::Zilla.  The C<prereqs>
+#pod attribute on your Dist::Zilla object is a Dist::Zilla::Prereqs object, and is
+#pod responsible for keeping track of the distribution's prerequisites.
+#pod
+#pod In fact, a Dist::Zilla::Prereqs object is just a thin layer over a
+#pod L<CPAN::Meta::Prereqs> object, stored in the C<cpan_meta_prereqs> attribute.
+#pod
+#pod Almost everything this object does is proxied to the CPAN::Meta::Prereqs
+#pod object, so you should really read how I<that> works.
+#pod
+#pod Dist::Zilla::Prereqs proxies the following methods to the CPAN::Meta::Prereqs
+#pod object:
+#pod
+#pod =for :list
+#pod * finalize
+#pod * is_finalized
+#pod * requirements_for
+#pod * as_string_hash
+#pod
+#pod =cut
 
 has cpan_meta_prereqs => (
   is  => 'ro',
@@ -30,6 +48,8 @@ has cpan_meta_prereqs => (
 
 # storing this is sort of gross, but MakeMaker winds up needing the same data
 # anyway. -- xdg, 2013-10-22
+# This does *not* contain configure requires, as MakeMaker explicitly should
+# not have it in its fallback prereqs.
 has merged_requires => (
   is => 'ro',
   isa => 'CPAN::Meta::Requirements',
@@ -37,6 +57,26 @@ has merged_requires => (
   default => sub { CPAN::Meta::Requirements->new },
 );
 
+#pod =method register_prereqs
+#pod
+#pod   $prereqs->register_prereqs(%prereqs);
+#pod
+#pod   $prereqs->register_prereqs(\%arg, %prereqs);
+#pod
+#pod This method adds new minimums to the prereqs object.  If a hashref is the first
+#pod arg, it may have entries for C<phase> and C<type> to indicate what kind of
+#pod prereqs are being registered.  (For more information on phase and type, see
+#pod L<CPAN::Meta::Spec>.)  For example, you might say:
+#pod
+#pod   $prereqs->register_prereqs(
+#pod     { phase => 'test', type => 'recommends' },
+#pod     'Test::Foo' => '1.23',
+#pod     'XML::YZZY' => '2.01',
+#pod   );
+#pod
+#pod If not given, phase and type default to runtime and requires, respectively.
+#pod
+#pod =cut
 
 sub register_prereqs {
   my $self = shift;
@@ -102,7 +142,7 @@ Dist::Zilla::Prereqs - the prerequisites of a Dist::Zilla distribution
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -162,11 +202,11 @@ If not given, phase and type default to runtime and requires, respectively.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
