@@ -1,13 +1,20 @@
-package Dist::Zilla::Role::AfterBuild;
-{
-  $Dist::Zilla::Role::AfterBuild::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::AfterBuild 6.000; # TRIAL
 # ABSTRACT: something that runs after building is mostly complete
+
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod Plugins implementing this role have their C<after_build> method called once all
+#pod the files have been written out.  It is passed a hashref with the following
+#pod data:
+#pod
+#pod   build_root - the directory in which the dist was built
+#pod
+#pod =cut
 
 requires 'after_build';
 
@@ -25,7 +32,7 @@ Dist::Zilla::Role::AfterBuild - something that runs after building is mostly com
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -37,11 +44,11 @@ data:
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
