@@ -1,13 +1,18 @@
-package Dist::Zilla::Role::AfterRelease;
-{
-  $Dist::Zilla::Role::AfterRelease::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::AfterRelease 6.000; # TRIAL
 # ABSTRACT: something that runs after release is mostly complete
+
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod Plugins implementing this role have their C<after_release> method called once
+#pod the release is done. The archive filename, if one was built, is passed as the
+#pod sole argument.
+#pod
+#pod =cut
 
 requires 'after_release';
 
@@ -25,20 +30,21 @@ Dist::Zilla::Role::AfterRelease - something that runs after release is mostly co
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
-Plugins implementing this role have their C<after_release> method called
-once the release is done.
+Plugins implementing this role have their C<after_release> method called once
+the release is done. The archive filename, if one was built, is passed as the
+sole argument.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
