@@ -1,13 +1,17 @@
-package Dist::Zilla::Role::BeforeBuild;
-{
-  $Dist::Zilla::Role::BeforeBuild::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::BeforeBuild 6.000; # TRIAL
 # ABSTRACT: something that runs before building really begins
+
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod Plugins implementing this role have their C<before_build> method called
+#pod before any other plugins are consulted.
+#pod
+#pod =cut
 
 requires 'before_build';
 
@@ -25,7 +29,7 @@ Dist::Zilla::Role::BeforeBuild - something that runs before building really begi
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -34,11 +38,11 @@ before any other plugins are consulted.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
