@@ -1,13 +1,17 @@
-package Dist::Zilla::Role::BeforeRelease;
-{
-  $Dist::Zilla::Role::BeforeRelease::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::BeforeRelease 6.000; # TRIAL
 # ABSTRACT: something that runs before release really begins
+
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod Plugins implementing this role have their C<before_release> method
+#pod called before the release is actually done.
+#pod
+#pod =cut
 
 requires 'before_release';
 
@@ -25,7 +29,7 @@ Dist::Zilla::Role::BeforeRelease - something that runs before release really beg
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -34,11 +38,11 @@ called before the release is actually done.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
