@@ -1,13 +1,23 @@
-package Dist::Zilla::Role::BuildRunner;
-{
-  $Dist::Zilla::Role::BuildRunner::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::BuildRunner 6.000; # TRIAL
 # ABSTRACT: something used as a delegating agent during 'dzil run'
+
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod Plugins implementing this role have their C<build> method called during
+#pod C<dzil run>.  It's passed the root directory of the build test dir.
+#pod
+#pod =head1 REQUIRED METHODS
+#pod
+#pod =head2 build
+#pod
+#pod This method will throw an exception on failure.
+#pod
+#pod =cut
 
 requires 'build';
 
@@ -25,7 +35,7 @@ Dist::Zilla::Role::BuildRunner - something used as a delegating agent during 'dz
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -40,11 +50,11 @@ This method will throw an exception on failure.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
