@@ -1,8 +1,6 @@
-package Dist::Zilla::Role::Chrome;
-{
-  $Dist::Zilla::Role::Chrome::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::Chrome 6.000; # TRIAL
 # ABSTRACT: something that provides a user interface for Dist::Zilla
+
 use Moose::Role;
 
 use namespace::autoclean;
@@ -27,15 +25,15 @@ Dist::Zilla::Role::Chrome - something that provides a user interface for Dist::Z
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
