@@ -1,13 +1,19 @@
-package Dist::Zilla::Role::EncodingProvider;
-{
-  $Dist::Zilla::Role::EncodingProvider::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::EncodingProvider 6.000; # TRIAL
 # ABSTRACT: something that sets a files' encoding
+
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod EncodingProvider plugins do their work after files are gathered, but before
+#pod they're munged.  They're meant to set the C<encoding> on files.
+#pod
+#pod The method C<set_file_encodings> is called with no arguments.
+#pod
+#pod =cut
 
 requires 'set_file_encodings';
 
@@ -25,7 +31,7 @@ Dist::Zilla::Role::EncodingProvider - something that sets a files' encoding
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -36,11 +42,11 @@ The method C<set_file_encodings> is called with no arguments.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
