@@ -1,8 +1,6 @@
-package Dist::Zilla::Role::ExecFiles;
-{
-  $Dist::Zilla::Role::ExecFiles::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::ExecFiles 6.000; # TRIAL
 # ABSTRACT: something that finds files to install as executables
+
 use Moose::Role;
 with 'Dist::Zilla::Role::FileFinder';
 
@@ -14,7 +12,10 @@ sub find_files {
   my ($self) = @_;
 
   my $dir = $self->dir;
-  my $files = $self->zilla->files->grep(sub { index($_->name, "$dir/") == 0 });
+  my $files = [
+    grep { index($_->name, "$dir/") == 0 }
+      @{ $self->zilla->files }
+  ];
 }
 
 1;
@@ -31,15 +32,15 @@ Dist::Zilla::Role::ExecFiles - something that finds files to install as executab
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
