@@ -1,14 +1,24 @@
-package Dist::Zilla::Role::FileInjector;
-{
-  $Dist::Zilla::Role::FileInjector::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::FileInjector 6.000; # TRIAL
 # ABSTRACT: something that can add files to the distribution
+
 use Moose::Role;
 
 use namespace::autoclean;
 
-use Moose::Autobox;
-
+#pod =head1 DESCRIPTION
+#pod
+#pod This role should be implemented by any plugin that plans to add files into the
+#pod distribution.  It provides one method (C<L</add_file>>, documented below),
+#pod which adds a file to the distribution, noting the place of addition.
+#pod
+#pod =method add_file
+#pod
+#pod   $plugin->add_file($dzil_file);
+#pod
+#pod This adds a file to the distribution, setting the file's C<added_by> attribute
+#pod as it does so.
+#pod
+#pod =cut
 
 sub add_file {
   my ($self, $file) = @_;
@@ -19,7 +29,7 @@ sub add_file {
   );
 
   $self->log_debug([ 'adding file %s', $file->name ]);
-  $self->zilla->files->push($file);
+  push @{ $self->zilla->files }, $file;
 }
 
 1;
@@ -36,7 +46,7 @@ Dist::Zilla::Role::FileInjector - something that can add files to the distributi
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -55,11 +65,11 @@ as it does so.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
