@@ -1,13 +1,19 @@
-package Dist::Zilla::Role::FilePruner;
-{
-  $Dist::Zilla::Role::FilePruner::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::FilePruner 6.000; # TRIAL
 # ABSTRACT: something that removes found files from the distribution
+
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod Plugins implementing FilePruner have their C<prune_files> method called once
+#pod all the L<FileGatherer|Dist::Zilla::Role::FileGatherer> plugins have been
+#pod called.  They are expected to (optionally) remove files from the list of files
+#pod to be included in the distribution.
+#pod
+#pod =cut
 
 requires 'prune_files';
 
@@ -25,7 +31,7 @@ Dist::Zilla::Role::FilePruner - something that removes found files from the dist
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -36,11 +42,11 @@ to be included in the distribution.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
