@@ -1,8 +1,6 @@
-package Dist::Zilla::Role::InstallTool;
-{
-  $Dist::Zilla::Role::InstallTool::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::InstallTool 6.000; # TRIAL
 # ABSTRACT: something that creates an install program for a dist
+
 use Moose::Role;
 with qw(
   Dist::Zilla::Role::Plugin
@@ -11,8 +9,16 @@ with qw(
 
 use namespace::autoclean;
 
-use Moose::Autobox;
-
+#pod =head1 DESCRIPTION
+#pod
+#pod Plugins implementing InstallTool have their C<setup_installer> method called to
+#pod inject files after all other file injection and munging has taken place.
+#pod They're expected to produce files needed to make the distribution
+#pod installable, like F<Makefile.PL> or F<Build.PL> and add them with the
+#pod C<add_file> method provided by L<Dist::Zilla::Role::FileInjector>, which is
+#pod also composed by this role.
+#pod
+#pod =cut
 
 requires 'setup_installer';
 
@@ -30,7 +36,7 @@ Dist::Zilla::Role::InstallTool - something that creates an install program for a
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -43,11 +49,11 @@ also composed by this role.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
