@@ -1,15 +1,30 @@
-package Dist::Zilla::Role::MintingProfile;
-{
-  $Dist::Zilla::Role::MintingProfile::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::MintingProfile 6.000; # TRIAL
 # ABSTRACT: something that can find a minting profile dir
+
 use Moose::Role;
 
 use namespace::autoclean;
 
 use File::ShareDir;
-use Path::Class;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod Plugins implementing this role should provide C<profile_dir> method, which,
+#pod given a minting profile name, returns its directory.
+#pod
+#pod The minting profile is a directory, containing arbitrary files used during
+#pod creation of new distribution. Among other things notably, it should contain the
+#pod 'profile.ini' file, listing the plugins used for minter initialization.
+#pod
+#pod The default implementation C<profile_dir> looks in the module's
+#pod L<ShareDir|File::ShareDir>.
+#pod
+#pod After installing your profile, users will be able to start a new distribution,
+#pod based on your profile with the:
+#pod
+#pod   $ dzil new -P Provider -p profile_name Distribution::Name
+#pod
+#pod =cut
 
 requires 'profile_dir';
 
@@ -27,7 +42,7 @@ Dist::Zilla::Role::MintingProfile - something that can find a minting profile di
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -48,11 +63,11 @@ based on your profile with the:
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
