@@ -1,22 +1,26 @@
-package Dist::Zilla::Role::MintingProfile::ShareDir;
-{
-  $Dist::Zilla::Role::MintingProfile::ShareDir::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::MintingProfile::ShareDir 6.000; # TRIAL
 # ABSTRACT: something that keeps its minting profile in a sharedir
+
 use Moose::Role;
 with 'Dist::Zilla::Role::MintingProfile';
 
 use namespace::autoclean;
 
 use File::ShareDir;
-use Path::Class;
+use Dist::Zilla::Path;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod This role includes L<Dist::Zilla::Role::MintingProfile>, providing a
+#pod C<profile_dir> method that looks in the I<module>'s L<ShareDir|File::ShareDir>.
+#pod
+#pod =cut
 
 sub profile_dir {
   my ($self, $profile_name) = @_;
 
-  my $profile_dir = dir( File::ShareDir::module_dir($self->meta->name) )
-                  ->subdir( $profile_name );
+  my $profile_dir = path( File::ShareDir::module_dir($self->meta->name) )
+                  ->child( $profile_name );
 
   return $profile_dir if -d $profile_dir;
 
@@ -37,7 +41,7 @@ Dist::Zilla::Role::MintingProfile::ShareDir - something that keeps its minting p
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -46,11 +50,11 @@ C<profile_dir> method that looks in the I<module>'s L<ShareDir|File::ShareDir>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
