@@ -1,8 +1,6 @@
-package Dist::Zilla::Role::ModuleMaker;
-{
-  $Dist::Zilla::Role::ModuleMaker::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::ModuleMaker 6.000; # TRIAL
 # ABSTRACT: something that injects module files into the dist
+
 use Moose::Role;
 with qw(
   Dist::Zilla::Role::Plugin
@@ -11,6 +9,19 @@ with qw(
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod Plugins implementing this role have their C<make_module> method called for each
+#pod module requesting creation by the plugin with this name.  It is passed a
+#pod hashref with the following data:
+#pod
+#pod   name - the name of the module to make (a MooseX::Types::Perl::ModuleName)
+#pod
+#pod Classes composing this role also compose
+#pod L<FileInjector|Dist::Zilla::Role::FileInjector> and are expected to inject a
+#pod file for the module being created.
+#pod
+#pod =cut
 
 requires 'make_module';
 
@@ -28,7 +39,7 @@ Dist::Zilla::Role::ModuleMaker - something that injects module files into the di
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -44,11 +55,11 @@ file for the module being created.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
