@@ -1,11 +1,19 @@
-package Dist::Zilla::Role::NameProvider;
-{
-  $Dist::Zilla::Role::NameProvider::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::NameProvider 6.000; # TRIAL
 # ABSTRACT: something that provides a name for the dist
+
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
+#pod =head1 DESCRIPTION
+#pod
+#pod Plugins implementing this role must provide a C<provide_name> method that
+#pod will be called when setting the dist's name.
+#pod
+#pod If a NameProvider offers a name but one has already been set, an
+#pod exception will be raised.  If C<provide_name> returns undef, it will be
+#pod ignored.
+#pod
+#pod =cut
 
 requires 'provide_name';
 
@@ -24,7 +32,7 @@ Dist::Zilla::Role::NameProvider - something that provides a name for the dist
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -37,11 +45,11 @@ ignored.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
