@@ -1,12 +1,18 @@
-package Dist::Zilla::Role::PluginBundle;
-{
-  $Dist::Zilla::Role::PluginBundle::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::PluginBundle 6.000; # TRIAL
 # ABSTRACT: something that bundles a bunch of plugins
+
 use Moose::Role;
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod When loading configuration, if the config reader encounters a PluginBundle, it
+#pod will replace its place in the plugin list with the result of calling its
+#pod C<bundle_config> method, which will be passed a Config::MVP::Section to
+#pod configure the bundle.
+#pod
+#pod =cut
 
 sub register_component {
   my ($class, $name, $arg, $self) = @_;
@@ -30,7 +36,7 @@ Dist::Zilla::Role::PluginBundle - something that bundles a bunch of plugins
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -41,11 +47,11 @@ configure the bundle.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
