@@ -1,16 +1,35 @@
-package Dist::Zilla::Role::PluginBundle::Easy;
-{
-  $Dist::Zilla::Role::PluginBundle::Easy::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::PluginBundle::Easy 6.000; # TRIAL
 # ABSTRACT: something that bundles a bunch of plugins easily
 # This plugin was originally contributed by Christopher J. Madsen
+
 use Moose::Role;
 with 'Dist::Zilla::Role::PluginBundle';
 
 use namespace::autoclean;
 
+#pod =head1 SYNOPSIS
+#pod
+#pod   package Dist::Zilla::PluginBundle::Example;
+#pod   use Moose;
+#pod   with 'Dist::Zilla::Role::PluginBundle::Easy';
+#pod
+#pod   sub configure {
+#pod     my $self = shift;
+#pod
+#pod     $self->add_plugins('VersionFromModule');
+#pod     $self->add_bundle('Basic');
+#pod   }
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod This role builds upon the PluginBundle role, adding methods to take most of the
+#pod grunt work out of creating a bundle.  It supplies the C<bundle_config> method
+#pod for you.  In exchange, you must supply a C<configure> method, which will store
+#pod the bundle's configuration in the C<plugins> attribute by calling
+#pod C<add_plugins> and/or C<add_bundle>.
+#pod
+#pod =cut
 
-use Moose::Autobox;
 use MooseX::Types::Moose qw(Str ArrayRef HashRef);
 
 use String::RewritePrefix 0.005
@@ -31,6 +50,12 @@ use namespace::autoclean;
 
 requires 'configure';
 
+#pod =attr name
+#pod
+#pod This is the bundle name, taken from the Section passed to
+#pod C<bundle_config>.
+#pod
+#pod =cut
 
 has name => (
   is       => 'ro',
@@ -38,6 +63,12 @@ has name => (
   required => 1,
 );
 
+#pod =attr payload
+#pod
+#pod This hashref contains the bundle's parameters (if any), taken from the
+#pod Section passed to C<bundle_config>.
+#pod
+#pod =cut
 
 has payload => (
   is       => 'ro',
@@ -45,6 +76,13 @@ has payload => (
   required => 1,
 );
 
+#pod =attr plugins
+#pod
+#pod This arrayref contains the configuration that will be returned by
+#pod C<bundle_config>.  You normally modify this by using the
+#pod C<add_plugins> and C<add_bundle> methods.
+#pod
+#pod =cut
 
 has plugins => (
   is       => 'ro',
@@ -59,9 +97,27 @@ sub bundle_config {
 
   $self->configure;
 
-  return $self->plugins->flatten;
+  return @{ $self->plugins };
 }
 
+#pod =method add_plugins
+#pod
+#pod   $self->add_plugins('Plugin1', [ Plugin2 => \%plugin2config ])
+#pod
+#pod Use this method to add plugins to your bundle.
+#pod
+#pod It is passed a list of plugin specifiers, which can be one of a few things:
+#pod
+#pod =for :list
+#pod * a plugin moniker (like you might provide in your config file)
+#pod * an arrayref of: C<< [ $moniker, $plugin_name, \%plugin_config ] >>
+#pod
+#pod In the case of an arrayref, both C<$plugin_name> and C<\%plugin_config> are
+#pod optional.
+#pod
+#pod The plugins are added to the config in the order given.
+#pod
+#pod =cut
 
 sub add_plugins {
   my ($self, @plugin_specs) = @_;
@@ -90,6 +146,14 @@ sub add_plugins {
   }
 }
 
+#pod =method add_bundle
+#pod
+#pod   $self->add_bundle(BundleName => \%bundle_config)
+#pod
+#pod Use this method to add all the plugins from another bundle to your bundle.  If
+#pod you omit C<%bundle_config>, an empty hashref will be supplied.
+#pod
+#pod =cut
 
 sub add_bundle {
   my ($self, $bundle, $payload) = @_;
@@ -105,15 +169,28 @@ sub add_bundle {
 
   $bundle = "\@$bundle" unless $bundle =~ /^@/;
 
-  $self->plugins->push(
+  push @{ $self->plugins },
     $package->bundle_config({
       name    => $self->name . '/' . $bundle,
       package => $package,
       payload => $payload,
-    })
-  );
+    });
 }
 
+#pod =method config_slice
+#pod
+#pod   $hash_ref = $self->config_slice(arg1, { arg2 => 'plugin_arg2' })
+#pod
+#pod Use this method to extract parameters from your bundle's C<payload> so
+#pod that you can pass them to a plugin or subsidiary bundle.  It supports
+#pod easy renaming of parameters, since a plugin may expect a parameter
+#pod name that's too generic to be suitable for a bundle.
+#pod
+#pod Each arg is either a key in C<payload>, or a hashref that maps keys in
+#pod C<payload> to keys in the hash being constructed.  If any specified
+#pod key does not exist in C<payload>, then it is omitted from the result.
+#pod
+#pod =cut
 
 sub config_slice {
   my $self = shift;
@@ -149,7 +226,7 @@ Dist::Zilla::Role::PluginBundle::Easy - something that bundles a bunch of plugin
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 SYNOPSIS
 
@@ -208,7 +285,7 @@ a plugin moniker (like you might provide in your config file)
 
 =item *
 
-an arrayref of: C<< [ $moniker, $plugin_name, \%plugin_config >>
+an arrayref of: C<< [ $moniker, $plugin_name, \%plugin_config ] >>
 
 =back
 
@@ -239,11 +316,11 @@ key does not exist in C<payload>, then it is omitted from the result.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
