@@ -1,13 +1,17 @@
-package Dist::Zilla::Role::PrereqSource;
-{
-  $Dist::Zilla::Role::PrereqSource::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::PrereqSource 6.000; # TRIAL
 # ABSTRACT: something that registers prerequisites
+
 use Moose::Role;
 with 'Dist::Zilla::Role::Plugin';
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod PrereqSource plugins have a C<register_prereqs> method that should register
+#pod prereqs with the Dist::Zilla object.
+#pod
+#pod =cut
 
 requires 'register_prereqs';
 
@@ -25,7 +29,7 @@ Dist::Zilla::Role::PrereqSource - something that registers prerequisites
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -34,11 +38,11 @@ prereqs with the Dist::Zilla object.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
