@@ -1,8 +1,6 @@
-package Dist::Zilla::Role::ShareDir;
-{
-  $Dist::Zilla::Role::ShareDir::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::ShareDir 6.000; # TRIAL
 # ABSTRACT: something that picks a directory to install as shared files
+
 use Moose::Role;
 with 'Dist::Zilla::Role::FileFinder';
 
@@ -28,15 +26,15 @@ Dist::Zilla::Role::ShareDir - something that picks a directory to install as sha
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
