@@ -1,8 +1,6 @@
-package Dist::Zilla::Role::Stash;
-{
-  $Dist::Zilla::Role::Stash::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::Stash 6.000; # TRIAL
 # ABSTRACT: something that stores options or data for later reference
+
 use Moose::Role;
 
 use namespace::autoclean;
@@ -39,15 +37,15 @@ Dist::Zilla::Role::Stash - something that stores options or data for later refer
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
