@@ -1,13 +1,17 @@
-package Dist::Zilla::Role::Stash::Authors;
-{
-  $Dist::Zilla::Role::Stash::Authors::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::Stash::Authors 6.000; # TRIAL
+# ABSTRACT: a stash that provides a list of author strings
+
 use Moose::Role;
 with 'Dist::Zilla::Role::Stash';
-# ABSTRACT: a stash that provides a list of author strings
 
 use namespace::autoclean;
 
+#pod =head1 OVERVIEW
+#pod
+#pod An Authors stash must provide an C<authors> method that returns an arrayref of
+#pod author strings, generally in the form "Name <email>".
+#pod
+#pod =cut
 
 requires 'authors';
 
@@ -25,7 +29,7 @@ Dist::Zilla::Role::Stash::Authors - a stash that provides a list of author strin
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 OVERVIEW
 
@@ -34,11 +38,11 @@ author strings, generally in the form "Name <email>".
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
