@@ -1,13 +1,16 @@
-package Dist::Zilla::Role::Stash::Login;
-{
-  $Dist::Zilla::Role::Stash::Login::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::Stash::Login 6.000; # TRIAL
+# ABSTRACT: a stash with username/password credentials
+
 use Moose::Role;
 with 'Dist::Zilla::Role::Stash';
-# ABSTRACT: a stash with username/password credentials
 
 use namespace::autoclean;
 
+#pod =head1 OVERVIEW
+#pod
+#pod A Login stash must provide a C<username> and C<password> method.
+#pod
+#pod =cut
 
 requires 'username';
 requires 'password';
@@ -26,7 +29,7 @@ Dist::Zilla::Role::Stash::Login - a stash with username/password credentials
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 OVERVIEW
 
@@ -34,11 +37,11 @@ A Login stash must provide a C<username> and C<password> method.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
