@@ -1,7 +1,4 @@
-package Dist::Zilla::Role::StubBuild;
-{
-  $Dist::Zilla::Role::StubBuild::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::StubBuild 6.000; # TRIAL
 # ABSTRACT: provides an empty BUILD methods
 
 use Moose::Role;
@@ -22,15 +19,15 @@ Dist::Zilla::Role::StubBuild - provides an empty BUILD methods
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
