@@ -1,15 +1,26 @@
-package Dist::Zilla::Role::TextTemplate;
-{
-  $Dist::Zilla::Role::TextTemplate::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Role::TextTemplate 6.000; # TRIAL
 # ABSTRACT: something that renders a Text::Template template string
+
 use Moose::Role;
 
 use namespace::autoclean;
 
+#pod =head1 DESCRIPTION
+#pod
+#pod Plugins implementing TextTemplate may call their own C<L</fill_in_string>>
+#pod method to render templates using L<Text::Template|Text::Template>.
+#pod
+#pod =cut
 
 use Text::Template;
 
+#pod =attr delim
+#pod
+#pod This attribute (which can't easily be set!) is a two-element array reference
+#pod returning the Text::Template delimiters to use.  It defaults to C<{{> and
+#pod C<}}>.
+#pod
+#pod =cut
 
 # XXX: Later, add a way to set this in config. -- rjbs, 2008-06-02
 has delim => (
@@ -20,6 +31,18 @@ has delim => (
   default  => sub { [ qw(  {{  }}  ) ] },
 );
 
+#pod =method fill_in_string
+#pod
+#pod   my $rendered = $plugin->fill_in_string($template, \%stash, \%arg);
+#pod
+#pod This uses Text::Template to fill in the given template using the variables
+#pod given in the C<%stash>.  The stash becomes the HASH argument to Text::Template,
+#pod so scalars must be scalar references rather than plain scalars.
+#pod
+#pod C<%arg> is dereferenced and passed in as extra arguments to Text::Template's
+#pod C<new> routine.
+#pod
+#pod =cut
 
 sub fill_in_string {
   my ($self, $string, $stash, $arg) = @_;
@@ -38,7 +61,7 @@ sub fill_in_string {
   $self->log_fatal("Could not create a Text::Template object from:\n$string")
     unless $tmpl;
 
-  my $content = $tmpl->fill_in(HASH => $stash);
+  my $content = $tmpl->fill_in(%$arg, HASH => $stash);
 
   $self->log_fatal("Filling in the template returned undef for:\n$string")
     unless defined $content;
@@ -60,7 +83,7 @@ Dist::Zilla::Role::TextTemplate - something that renders a Text::Template templa
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -86,15 +109,15 @@ given in the C<%stash>.  The stash becomes the HASH argument to Text::Template,
 so scalars must be scalar references rather than plain scalars.
 
 C<%arg> is dereferenced and passed in as extra arguments to Text::Template's
-C<fill_in_string> routine.
+C<new> routine.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
