@@ -1,12 +1,16 @@
-package Dist::Zilla::Stash::PAUSE;
-{
-  $Dist::Zilla::Stash::PAUSE::VERSION = '5.003'; # TRIAL
-}
-use Moose;
+package Dist::Zilla::Stash::PAUSE 6.000; # TRIAL
 # ABSTRACT: a stash of your PAUSE credentials
 
+use Moose;
+
 use namespace::autoclean;
 
+#pod =head1 OVERVIEW
+#pod
+#pod The PAUSE stash is a L<Login|Dist::Zilla::Role::Stash::Login> stash generally
+#pod used for uploading to PAUSE.
+#pod
+#pod =cut
 
 sub mvp_aliases {
   return { user => 'username' };
@@ -40,7 +44,7 @@ Dist::Zilla::Stash::PAUSE - a stash of your PAUSE credentials
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 OVERVIEW
 
@@ -49,11 +53,11 @@ used for uploading to PAUSE.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
