@@ -1,10 +1,8 @@
-package Dist::Zilla::Stash::Rights;
-{
-  $Dist::Zilla::Stash::Rights::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Stash::Rights 6.000; # TRIAL
+# ABSTRACT: a stash of your default licensing terms
+
 use Moose;
 with 'Dist::Zilla::Role::Stash';
-# ABSTRACT: a stash of your default licensing terms
 
 use namespace::autoclean;
 
@@ -40,15 +38,15 @@ Dist::Zilla::Stash::Rights - a stash of your default licensing terms
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
