@@ -1,10 +1,8 @@
-package Dist::Zilla::Stash::User;
-{
-  $Dist::Zilla::Stash::User::VERSION = '5.003'; # TRIAL
-}
-use Moose;
+package Dist::Zilla::Stash::User 6.000; # TRIAL
 # ABSTRACT: a stash of user name and email
 
+use Moose;
+
 use namespace::autoclean;
 
 has name => (
@@ -40,15 +38,15 @@ Dist::Zilla::Stash::User - a stash of user name and email
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
