@@ -1,10 +1,8 @@
-package Dist::Zilla::Tester;
-{
-  $Dist::Zilla::Tester::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Tester 6.000; # TRIAL
+# ABSTRACT: a testing-enabling stand-in for Dist::Zilla
+
 use Moose;
 extends 'Dist::Zilla::Dist::Builder';
-# ABSTRACT: a testing-enabling stand-in for Dist::Zilla
 
 # XXX: Adding this autoclean causes problem.  "Builder" and "Minter" do not
 # show in tests.  I'm really not sure why. -- rjbs, 2011-08-19
@@ -15,7 +13,7 @@ use Dist::Zilla::Chrome::Test;
 use File::pushd ();
 use File::Spec;
 use File::Temp;
-use Path::Tiny;
+use Dist::Zilla::Path;
 
 use Sub::Exporter::Util ();
 use Sub::Exporter -setup => {
@@ -29,7 +27,14 @@ use Sub::Exporter -setup => {
 
 sub from_config {
   my ($self, @arg) = @_;
-  $self->builder->from_config(@arg);
+
+  # The only thing using a local time zone should be NextRelease.  Normally it
+  # defaults to "local," but since some users won't have an automatically
+  # determinable time zone, we'll switch to not-local times for testing.
+  # -- rjbs, 2015-11-26
+  local $Dist::Zilla::Plugin::NextRelease::DEFAULT_TIME_ZONE = 'GMT';
+
+  return $self->builder->from_config(@arg);
 }
 
 sub builder { 'Dist::Zilla::Tester::_Builder' }
@@ -37,12 +42,33 @@ sub builder { 'Dist::Zilla::Tester::_Builder' }
 sub minter { 'Dist::Zilla::Tester::_Minter' }
 
 {
-  package Dist::Zilla::Tester::_Role;
-{
-  $Dist::Zilla::Tester::_Role::VERSION = '5.003'; # TRIAL
-}
+  package
+    Dist::Zilla::Tester::_Role;
+
   use Moose::Role;
 
+  has tempdir_root => (
+    is => 'rw', isa => 'Str|Undef',
+    writer => '_set_tempdir_root',
+  );
+  has tempdir_obj => (
+    is => 'ro', isa => 'File::Temp::Dir',
+    clearer => '_clear_tempdir_obj',
+    writer => '_set_tempdir_obj',
+  );
+
+  sub DEMOLISH {}
+  around DEMOLISH => sub {
+    my $orig = shift;
+    my $self = shift;
+
+    # File::Temp deletes the directory when it goes out of scope
+    $self->_clear_tempdir_obj;
+
+    rmdir $self->tempdir_root if $self->tempdir_root;
+    return $self->$orig(@_);
+  };
+
   has tempdir => (
     is   => 'ro',
     writer   => '_set_tempdir',
@@ -67,16 +93,16 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
   sub slurp_file {
     my ($self, $filename) = @_;
 
-    Path::Tiny::path(
-      $self->tempdir->file($filename)
+    Dist::Zilla::Path::path(
+      $self->tempdir->child($filename)
     )->slurp_utf8;
   }
 
   sub slurp_file_raw {
     my ($self, $filename) = @_;
 
-    Path::Tiny::path(
-      $self->tempdir->file($filename)
+    Dist::Zilla::Path::path(
+      $self->tempdir->child($filename)
     )->slurp_raw;
   }
 
@@ -86,16 +112,19 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
 }
 
 {
-  package Dist::Zilla::Tester::_Builder;
-{
-  $Dist::Zilla::Tester::_Builder::VERSION = '5.003'; # TRIAL
-}
+  package Dist::Zilla::Tester::_Builder 6.000; # TRIAL
+
   use Moose;
   extends 'Dist::Zilla::Dist::Builder';
   with 'Dist::Zilla::Tester::_Role';
 
   use File::Copy::Recursive qw(dircopy);
-  use Path::Class;
+  use Dist::Zilla::Path;
+
+  our $Log_Events = [];
+  sub most_recent_log_events {
+    return @{ $Log_Events }
+  }
 
   around from_config => sub {
     my ($orig, $self, $arg, $tester_arg) = @_;
@@ -110,37 +139,48 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
 
     mkdir $tempdir_root if defined $tempdir_root and not -d $tempdir_root;
 
-    my $tempdir = dir( File::Temp::tempdir(
+    my $tempdir_obj = File::Temp->newdir(
         CLEANUP => 1,
         (defined $tempdir_root ? (DIR => $tempdir_root) : ()),
-    ))->absolute;
+    );
+    my $tempdir = path($tempdir_obj)->absolute;
 
-    my $root = $tempdir->subdir('source');
+    my $root = $tempdir->child('source');
     $root->mkpath;
 
     dircopy($source, $root);
 
     if ($tester_arg->{also_copy}) {
       while (my ($src, $dest) = each %{ $tester_arg->{also_copy} }) {
-        dircopy($src, $tempdir->subdir($dest));
+        dircopy($src, $tempdir->child($dest));
       }
     }
 
     if (my $files = $tester_arg->{add_files}) {
       while (my ($name, $content) = each %$files) {
-        my $fn = $tempdir->file($name);
-        $fn->dir->mkpath;
-        Path::Tiny::path($fn)->spew_utf8($content);
+        die "Unix path '$name' does not seem to be portable to the current OS"
+          if !unix_path_seems_portable($name);
+        my $fn = $tempdir->child($name);
+        $fn->parent->mkpath;
+        Dist::Zilla::Path::path($fn)->spew_utf8($content);
       }
     }
 
     local $arg->{dist_root} = "$root";
     local $arg->{chrome} = Dist::Zilla::Chrome::Test->new;
 
+    $Log_Events = $arg->{chrome}->logger->events;
+
     local @INC = map {; ref($_) ? $_ : File::Spec->rel2abs($_) } @INC;
 
+    local $ENV{DZIL_GLOBAL_CONFIG_ROOT};
+    $ENV{DZIL_GLOBAL_CONFIG_ROOT} = $tester_arg->{global_config_root}
+      if defined $tester_arg->{global_config_root};
+
     my $zilla = $self->$orig($arg);
 
+    $zilla->_set_tempdir_root($tempdir_root);
+    $zilla->_set_tempdir_obj($tempdir_obj);
     $zilla->_set_tempdir($tempdir);
 
     return $zilla;
@@ -154,7 +194,7 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
     my $wd = File::pushd::pushd($self->root);
 
     $target ||= do {
-      my $target = dir($self->tempdir)->subdir('build');
+      my $target = path($self->tempdir)->child('build');
       $target->mkpath;
       $target;
     };
@@ -173,25 +213,46 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
   };
 
   no Moose;
+
+  sub unix_path_seems_portable {
+    return 1 if $^O eq "linux"; # this check only makes sense on non-unixes
+
+    my ($unix_path) = @_;
+
+    # split the  $unix_path into 3 strings: $volume, $directories, $file; with:
+    my @native_parts = File::Spec->splitpath($unix_path); # current OS rules
+    my @unix_parts = File::Spec::Unix->splitpath($unix_path); # unix rules
+    return unless join(qq{\0}, @native_parts) eq join(qq{\0}, @unix_parts);
+
+    # split the $directories string into a list of the sub-directories; with:
+    my @native_dirs = File::Spec->splitdir($native_parts[1]); # current OS rules
+    my @unix_dirs = File::Spec::Unix->splitdir($unix_parts[1]); # unix rules
+    return unless join(qq{\0}, @native_dirs) eq join(qq{\0}, @unix_dirs);
+
+    return 1;
+  }
 }
 
 {
-  package Dist::Zilla::Tester::_Minter;
-{
-  $Dist::Zilla::Tester::_Minter::VERSION = '5.003'; # TRIAL
-}
+  package Dist::Zilla::Tester::_Minter 6.000; # TRIAL
+
   use Moose;
   extends 'Dist::Zilla::Dist::Minter';
   with 'Dist::Zilla::Tester::_Role';
 
   use File::Copy::Recursive qw(dircopy);
-  use Path::Class;
+  use Dist::Zilla::Path;
+
+  our $Log_Events = [];
+  sub most_recent_log_events {
+    return @{ $Log_Events }
+  }
 
   sub _mint_target_dir {
     my ($self) = @_;
 
     my $name = $self->name;
-    my $dir  = $self->tempdir->subdir('mint')->absolute;
+    my $dir  = $self->tempdir->child('mint')->absolute;
 
     $self->log_fatal("$dir already exists") if -e $dir;
 
@@ -201,7 +262,7 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
   sub _setup_global_config {
     my ($self, $dir, $arg) = @_;
 
-    my $config_base = $dir->file('config');
+    my $config_base = path($dir)->child('config');
 
     my $stash_registry = {};
 
@@ -230,19 +291,23 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
 
     mkdir $tempdir_root if defined $tempdir_root and not -d $tempdir_root;
 
-    my $tempdir = dir( File::Temp::tempdir(
+    my $tempdir_obj = File::Temp->newdir(
         CLEANUP => 1,
         (defined $tempdir_root ? (DIR => $tempdir_root) : ()),
-    ))->absolute;
+    );
+    my $tempdir = path($tempdir_obj)->absolute;
 
     local $arg->{chrome} = Dist::Zilla::Chrome::Test->new;
+    $Log_Events = $arg->{chrome}->logger->events;
 
     local @INC = map {; ref($_) ? $_ : File::Spec->rel2abs($_) } @INC;
 
-    local $ENV{DZIL_GLOBAL_CONFIG_ROOT} = $tester_arg->{global_config_root};
+    my $global_config_root = path($tester_arg->{global_config_root})->absolute;
+
+    local $ENV{DZIL_GLOBAL_CONFIG_ROOT} = $global_config_root;
 
     my $global_stashes = $self->_setup_global_config(
-      $tester_arg->{global_config_root},
+      $global_config_root,
       { chrome => $arg->{chrome} },
     );
 
@@ -250,6 +315,8 @@ sub minter { 'Dist::Zilla::Tester::_Minter' }
 
     my $zilla = $self->$orig($profile_data, $arg);
 
+    $zilla->_set_tempdir_root($tempdir_root);
+    $zilla->_set_tempdir_obj($tempdir_obj);
     $zilla->_set_tempdir($tempdir);
 
     return $zilla;
@@ -272,15 +339,15 @@ Dist::Zilla::Tester - a testing-enabling stand-in for Dist::Zilla
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
