@@ -1,13 +1,10 @@
 use strict;
 use warnings;
-package Dist::Zilla::Util;
-{
-  $Dist::Zilla::Util::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Util 6.000; # TRIAL
 # ABSTRACT: random snippets of code that Dist::Zilla wants
 
 use Carp ();
-use String::RewritePrefix 0.002; # better string context behavior
+use Encode ();
 
 {
   package
@@ -26,7 +23,7 @@ use String::RewritePrefix 0.002; # better string context behavior
     my ($self, $event) = @_;
     return if $self->{abstract};
     return $self->{abstract} = $1
-      if $event->{content}=~ /^\s*#+\s*ABSTRACT:\s*(.+)$/m;
+      if $event->{content}=~ /^\s*#+\s*ABSTRACT:[ \t]*(\S.*)$/m;
     return;
   }
   sub handle_event {
@@ -49,44 +46,70 @@ use String::RewritePrefix 0.002; # better string context behavior
       and $event->{content} =~ /^(?:\S+\s+)+?-+\s+(.+)\n$/s
     ) {
       $self->{abstract} = $1;
+      $self->{abstract} =~ s/\s+/\x20/g;
     }
   }
 }
 
+#pod =method abstract_from_file
+#pod
+#pod This method, I<which is likely to change or go away>, tries to guess the
+#pod abstract of a given file, assuming that it's Perl code.  It looks for a POD
+#pod C<=head1> section called "NAME" or a comment beginning with C<ABSTRACT:>.
+#pod
+#pod =cut
 
 sub abstract_from_file {
   my ($self, $file) = @_;
   my $e = Dist::Zilla::Util::PEA->_new;
-  $e->read_string($file->content);
+
+  my $chars = $file->content;
+  my $bytes = Encode::encode('UTF-8', $chars, Encode::FB_CROAK);
+
+  $e->read_string($bytes);
+
   return $e->{abstract};
 }
 
+#pod =method expand_config_package_name
+#pod
+#pod   my $pkg_name = Dist::Zilla::Util->expand_config_package_name($string);
+#pod
+#pod This method, I<which is likely to change or go away>, rewrites the given string
+#pod into a package name.
+#pod
+#pod Prefixes are rewritten as follows:
+#pod
+#pod =for :list
+#pod * C<=> becomes nothing
+#pod * C<@> becomes C<Dist::Zilla::PluginBundle::>
+#pod * C<%> becomes C<Dist::Zilla::Stash::>
+#pod * otherwise, C<Dist::Zilla::Plugin::> is prepended
+#pod
+#pod =cut
 
+use String::RewritePrefix 0.006 rewrite => {
+  -as => '_expand_config_package_name',
+  prefixes => {
+    '=' => '',
+    '@' => 'Dist::Zilla::PluginBundle::',
+    '%' => 'Dist::Zilla::Stash::',
+    ''  => 'Dist::Zilla::Plugin::',
+  },
+};
 sub expand_config_package_name {
-  my ($self, $package) = @_;
-
-  my $str = String::RewritePrefix->rewrite(
-    {
-      '=' => '',
-      '@' => 'Dist::Zilla::PluginBundle::',
-      '%' => 'Dist::Zilla::Stash::',
-      ''  => 'Dist::Zilla::Plugin::',
-    },
-    $package,
-  );
-
-  return $str;
+  shift; goto &_expand_config_package_name
 }
 
 sub _global_config_root {
-  require Path::Class;
-  return Path::Class::dir($ENV{DZIL_GLOBAL_CONFIG_ROOT}) if $ENV{DZIL_GLOBAL_CONFIG_ROOT};
+  require Dist::Zilla::Path;
+  return Dist::Zilla::Path::path($ENV{DZIL_GLOBAL_CONFIG_ROOT}) if $ENV{DZIL_GLOBAL_CONFIG_ROOT};
 
   require File::HomeDir;
   my $homedir = File::HomeDir->my_home
     or Carp::croak("couldn't determine home directory");
 
-  return Path::Class::dir($homedir)->subdir('.dzil');
+  return Dist::Zilla::Path::path($homedir)->child('.dzil');
 }
 
 sub _assert_loaded_class_version_ok {
@@ -100,9 +123,9 @@ sub _assert_loaded_class_version_ok {
   my $have_version = $pkg->VERSION;
   unless ($req->accepts_module($pkg => $have_version)) {
     die( sprintf
-      "%s version (%s) not match required version: %s\n",
+      "%s version (%s) does not match required version: %s\n",
       $pkg,
-      $have_version,
+      $have_version // 'undef',
       $version,
     );
   }
@@ -122,7 +145,7 @@ Dist::Zilla::Util - random snippets of code that Dist::Zilla wants
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 METHODS
 
@@ -134,19 +157,40 @@ C<=head1> section called "NAME" or a comment beginning with C<ABSTRACT:>.
 
 =head2 expand_config_package_name
 
-  my $pkg_name = Util->expand_config_package_name($string);
+  my $pkg_name = Dist::Zilla::Util->expand_config_package_name($string);
 
 This method, I<which is likely to change or go away>, rewrites the given string
-into a package name.  Consult L<Dist::Zilla::Config|Dist::Zilla::Config> for
-more information.
+into a package name.
+
+Prefixes are rewritten as follows:
+
+=over 4
+
+=item *
+
+C<=> becomes nothing
+
+=item *
+
+C<@> becomes C<Dist::Zilla::PluginBundle::>
+
+=item *
+
+C<%> becomes C<Dist::Zilla::Stash::>
+
+=item *
+
+otherwise, C<Dist::Zilla::Plugin::> is prepended
+
+=back
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
