@@ -1,14 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Util::AuthorDeps;
-{
-  $Dist::Zilla::Util::AuthorDeps::VERSION = '5.003'; # TRIAL
-}
+package Dist::Zilla::Util::AuthorDeps 6.000; # TRIAL
 # ABSTRACT: Utils for listing your distribution's author dependencies
 
 use Dist::Zilla::Util;
-use Path::Class;
-use List::MoreUtils ();
+use Path::Tiny;
+use List::Util 1.45 ();
 
 
 sub format_author_deps {
@@ -26,13 +23,12 @@ sub format_author_deps {
 sub extract_author_deps {
   my ($root, $missing) = @_;
 
-  my $ini = $root->file('dist.ini');
+  my $ini = path($root, 'dist.ini');
 
   die "dzil authordeps only works on dist.ini files, and you don't have one\n"
     unless -e $ini;
 
-  my $fh = $ini->openr;
-  binmode($fh, ":encoding(UTF-8)");
+  my $fh = $ini->openr_utf8;
 
   require Config::INI::Reader;
   my $config = Config::INI::Reader->read_handle($fh);
@@ -40,17 +36,19 @@ sub extract_author_deps {
   require CPAN::Meta::Requirements;
   my $reqs = CPAN::Meta::Requirements->new;
 
-  my @packs =
-    map  { s/\s.*//; $_ }
-    grep { $_ ne '_' }
-    keys %$config;
+  if (defined (my $license = $config->{_}->{license})) {
+    $license = 'Software::License::'.$license;
+    $reqs->add_minimum($license => 0);
+  }
 
-  foreach my $pack (@packs) {
+  for my $section ( sort keys %$config ) {
+    next if q[_] eq $section;
+    my $pack = $section;
+    $pack =~ s{\s*/.*$}{}; # trim optional space and slash-delimited suffix
 
     my $version = 0;
-    if(exists $config->{$pack} && exists $config->{$pack}->{':version'}) {
-      $version = $config->{$pack}->{':version'};
-    }
+    $version = $config->{$section}->{':version'} if exists $config->{$section}->{':version'};
+
     my $realname = Dist::Zilla::Util->expand_config_package_name($pack);
     $reqs->add_minimum($realname => $version);
   }
@@ -74,14 +72,16 @@ sub extract_author_deps {
   my @packages;
   while (<$fh>) {
     chomp;
-    next unless /\A\s*;\s*authordep\s*(\S+)\s*(=\s*(\S+))?\s*\z/;
-    my $ver = defined $3 ? $3 : "0";
+    next unless /\A\s*;\s*authordep\s*(\S+)\s*(?:=\s*([^;]+))?\s*/;
+    my $module = $1;
+    my $ver = $2 // "0";
+    $ver =~ s/\s+$//;
     # Any "; authordep " is inserted at the beginning of the list
     # in the file order so the user can control the order of at least a part of
     # the plugin list
-    push @packages, $1;
+    push @packages, $module;
     # And added to the requirements so we can use it later
-    $reqs->add_minimum($1 => $ver);
+    $reqs->add_string_requirement($module => $ver);
   }
 
   my $vermap = $reqs->as_string_hash;
@@ -99,14 +99,18 @@ sub extract_author_deps {
 
   # Now that we have a sorted list of packages, use that to build an array of
   # hashrefs for display.
-  require List::MoreUtils;
   require Class::Load;
 
   my @final =
     map { { $_ => $vermap->{$_} } }
-    grep { $missing ? (! Class::Load::try_load_class($_, ($vermap->{$_} ? {-version => $vermap->{$_}} : ()))) : 1 }
-    List::MoreUtils::uniq
-    @packages;
+    grep {
+      $missing
+        ? $_ eq 'perl'
+          ? ($vermap->{perl} ? !eval "use $vermap->{perl}; 1" : ())
+          : (! Class::Load::try_load_class($_, ($vermap->{$_} ? {-version => $vermap->{$_}} : ())))
+        : 1
+      }
+    List::Util::uniq(@packages);
 
   return \@final;
 }
@@ -125,15 +129,15 @@ Dist::Zilla::Util::AuthorDeps - Utils for listing your distribution's author dep
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
