@@ -1,14 +1,10 @@
 use strict;
 use warnings;
-package Test::DZil;
-{
-  $Test::DZil::VERSION = '5.003'; # TRIAL
-}
+package Test::DZil 6.000; # TRIAL
 # ABSTRACT: tools for testing Dist::Zilla plugins
 
-use Dist::Zilla::Tester;
 use Params::Util qw(_HASH0);
-use JSON 2;
+use JSON::MaybeXS;
 use Scalar::Util qw(blessed);
 use Test::Deep ();
 use YAML::Tiny;
@@ -26,22 +22,66 @@ use Sub::Exporter -setup => {
   groups  => [ default => [ qw(-all) ] ],
 };
 
+#pod =head1 DESCRIPTION
+#pod
+#pod Test::DZil provides routines for writing tests for Dist::Zilla plugins.
+#pod
+#pod =cut
 
+#pod =func Builder
+#pod
+#pod =func Minter
+#pod
+#pod   my $tzil = Builder->from_config(...);
+#pod
+#pod These return class names that subclass L<Dist::Zilla::Dist::Builder> or
+#pod L<Dist::Zilla::Dist::Minter>, respectively, with the L<Dist::Zilla::Tester>
+#pod behavior added.
+#pod
+#pod =cut
+
+sub Builder {
+  require Dist::Zilla::Tester;
+  Dist::Zilla::Tester::builder();
+}
+
+sub Minter {
+  require Dist::Zilla::Tester;
+  Dist::Zilla::Tester::minter();
+}
+
+#pod =func is_filelist
+#pod
+#pod   is_filelist( \@files_we_have, \@files_we_want, $desc );
+#pod
+#pod This test assertion compares two arrayrefs of filenames, taking care of slash
+#pod normalization and sorting.  C<@files_we_have> may also contain objects that
+#pod do L<Dist::Zilla::Role::File>.
+#pod
+#pod =cut
 
 sub is_filelist {
   my ($have, $want, $comment) = @_;
 
-  my @want = sort @$want;
-  my @have = sort map { my $str = (blessed $_ and
-                                   $_->DOES('Dist::Zilla::Role::File'))
-                            ? $_->name
-                            : $_;
-                        $str =~ s{\\}{/}g; $str } @$have;
+  my @want = @$want;
+  my @have = map { my $str = (blessed $_ and
+                              $_->DOES('Dist::Zilla::Role::File'))
+                       ? $_->name
+                       : $_;
+                   $str =~ s{\\}{/}g; $str } @$have;
 
   local $Test::Builder::Level = $Test::Builder::Level + 1;
-  Test::More::is_deeply(\@have, \@want, $comment);
+  Test::Deep::cmp_bag(\@have, \@want, $comment);
 }
 
+#pod =func is_yaml
+#pod
+#pod   is_yaml( $yaml_string, $want_struct, $comment );
+#pod
+#pod This test assertion deserializes the given YAML string and does a
+#pod C<L<cmp_deeply|Test::Deep/cmp_deeply>>.
+#pod
+#pod =cut
 
 sub is_yaml {
   my ($yaml, $want, $comment) = @_;
@@ -53,11 +93,19 @@ sub is_yaml {
   Test::Deep::cmp_deeply($have->[0], $want, $comment);
 }
 
+#pod =func is_json
+#pod
+#pod   is_json( $json_string, $want_struct, $comment );
+#pod
+#pod This test assertion deserializes the given JSON string and does a
+#pod C<L<cmp_deeply|Test::Deep/cmp_deeply>>.
+#pod
+#pod =cut
 
 sub is_json {
   my ($json, $want, $comment) = @_;
 
-  my $have = JSON->new->ascii(1)->decode($json)
+  my $have = JSON::MaybeXS->new(ascii => 1)->decode($json)
     or die "Cannot decode JSON";
 
   local $Test::Builder::Level = $Test::Builder::Level + 1;
@@ -76,7 +124,7 @@ sub _build_ini_builder {
 
     my $config = '';
 
-    for my $key (keys %$core_config) {
+    for my $key (sort keys %$core_config) {
       my @values = ref $core_config->{ $key }
                  ? @{ $core_config->{ $key } }
                  : $core_config->{ $key };
@@ -98,7 +146,7 @@ sub _build_ini_builder {
       $config .= ' / ' . $name if defined $name;
       $config .= "]\n";
 
-      for my $key (keys %$payload) {
+      for my $key (sort keys %$payload) {
         my @values = ref $payload->{ $key }
                    ? @{ $payload->{ $key } }
                    : $payload->{ $key };
@@ -113,11 +161,70 @@ sub _build_ini_builder {
   }
 }
 
+#pod =func dist_ini
+#pod
+#pod   my $ini_text = dist_ini(\%root_config, @plugins);
+#pod
+#pod This routine returns a string that could be used to populate a simple
+#pod F<dist.ini> file.  The C<%root_config> gives data for the "root" section of the
+#pod configuration.  To provide a line multiple times, provide an arrayref.  For
+#pod example, the root section could read:
+#pod
+#pod   {
+#pod     name   => 'Dist-Sample',
+#pod     author => [
+#pod       'J. Smith <jsmith@example.com>',
+#pod       'Q. Smith <qsmith@example.com>',
+#pod     ],
+#pod   }
+#pod
+#pod The root section is optional.
+#pod
+#pod Plugins can be given in a few ways:
+#pod
+#pod =begin :list
+#pod
+#pod = C<"PluginMoniker">
+#pod
+#pod = C<[ "PluginMoniker" ]>
+#pod
+#pod These become C<[PluginMoniker]>
+#pod
+#pod = C<[ "PluginMoniker", "PluginName" ]>
+#pod
+#pod This becomes C<[PluginMoniker / PluginName]>
+#pod
+#pod = C<[ "PluginMoniker", { ... } ]>
+#pod
+#pod = C<[ "PluginMoniker", "PluginName", { ... } ]>
+#pod
+#pod These use the given hashref as the parameters inside the section, with the same
+#pod semantics as the root section.
+#pod
+#pod =end :list
+#pod
+#pod =cut
 
 sub _dist_ini {
   _build_ini_builder;
 }
 
+#pod =func simple_ini
+#pod
+#pod This behaves exactly like C<dist_ini>, but it merges any given root config into
+#pod a starter config, which means that you can often skip any explicit root config.
+#pod The starter config may change slightly over time, but is something like this:
+#pod
+#pod   {
+#pod     name     => 'DZT-Sample',
+#pod     abstract => 'Sample DZ Dist',
+#pod     version  => '0.001',
+#pod     author   => 'E. Xavier Ample <example@example.org>',
+#pod     license  => 'Perl_5',
+#pod     copyright_holder => 'E. Xavier Ample',
+#pod   }
+#pod
+#pod =cut
 
 sub _simple_ini {
   _build_ini_builder({
@@ -144,7 +251,7 @@ Test::DZil - tools for testing Dist::Zilla plugins
 
 =head1 VERSION
 
-version 5.003
+version 6.000
 
 =head1 DESCRIPTION
 
@@ -243,11 +350,11 @@ The starter config may change slightly over time, but is something like this:
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES 🎃 <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Ricardo SIGNES.
+This software is copyright (c) 2016 by Ricardo SIGNES.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
